@@ -1,11 +1,12 @@
 from dagster import check
-from dagster.config.field_utils import check_user_facing_opt_config_param
 from dagster.core.definitions.config import is_callable_valid_config_arg
-from dagster.utils.backcompat import canonicalize_backcompat_args, rename_warning
+from dagster.core.definitions.configurable import AnonymousConfigurableDefinition
+
+from .definition_config_schema import convert_user_facing_definition_config_schema
 
 
-class LoggerDefinition(object):
-    '''Core class for defining loggers.
+class LoggerDefinition(AnonymousConfigurableDefinition):
+    """Core class for defining loggers.
 
     Loggers are pipeline-scoped logging handlers, which will be automatically invoked whenever
     solids in a pipeline log messages.
@@ -17,28 +18,22 @@ class LoggerDefinition(object):
         config_schema (Optional[ConfigSchema]): The schema for the config. Configuration data available in
             `init_context.logger_config`.
         description (Optional[str]): A human-readable description of this logger.
-    '''
+    """
 
-    def __init__(self, logger_fn, config_schema=None, description=None, config=None):
-        self._logger_fn = check.callable_param(logger_fn, 'logger_fn')
-        self._config_schema = canonicalize_backcompat_args(
-            check_user_facing_opt_config_param(config_schema, 'config_schema'),
-            'config_schema',
-            check_user_facing_opt_config_param(config, 'config'),
-            'config',
-            '0.9.0',
-        )
-        self._description = check.opt_str_param(description, 'description')
+    def __init__(
+        self,
+        logger_fn,
+        config_schema=None,
+        description=None,
+    ):
+        self._logger_fn = check.callable_param(logger_fn, "logger_fn")
+        self._config_schema = convert_user_facing_definition_config_schema(config_schema)
+        self._description = check.opt_str_param(description, "description")
 
     @property
     def logger_fn(self):
         return self._logger_fn
 
-    @property
-    def config_field(self):
-        rename_warning('config_schema', 'config_field', '0.9.0')
-        return self._config_schema
-
     @property
     def config_schema(self):
         return self._config_schema
@@ -47,9 +42,16 @@ class LoggerDefinition(object):
     def description(self):
         return self._description
 
+    def copy_for_configured(self, description, config_schema, _):
+        return LoggerDefinition(
+            config_schema=config_schema,
+            description=description or self.description,
+            logger_fn=self.logger_fn,
+        )
 
-def logger(config_schema=None, description=None, config=None):
-    '''Define a logger.
+
+def logger(config_schema=None, description=None):
+    """Define a logger.
 
     The decorated function should accept an :py:class:`InitLoggerContext` and return an instance of
     :py:class:`python:logging.Logger`. This function will become the ``logger_fn`` of an underlying
@@ -59,7 +61,7 @@ def logger(config_schema=None, description=None, config=None):
         config_schema (Optional[ConfigSchema]): The schema for the config. Configuration data available in
             `init_context.logger_config`.
         description (Optional[str]): A human-readable description of the logger.
-    '''
+    """
     # This case is for when decorator is used bare, without arguments.
     # E.g. @logger versus @logger()
     if callable(config_schema) and not is_callable_valid_config_arg(config_schema):
@@ -68,9 +70,7 @@ def logger(config_schema=None, description=None, config=None):
     def _wrap(logger_fn):
         return LoggerDefinition(
             logger_fn=logger_fn,
-            config_schema=canonicalize_backcompat_args(
-                config_schema, 'config_schema', config, 'config', '0.9.0'
-            ),
+            config_schema=config_schema,
             description=description,
         )
 
