@@ -1,18 +1,21 @@
+import inspect
 from collections import namedtuple
-from datetime import timedelta
-
-from dateutil.relativedelta import relativedelta
 
+import pendulum
 from dagster import check
+from dagster.core.definitions.job import RunRequest, SkipReason
 from dagster.core.definitions.schedule import ScheduleDefinition, ScheduleExecutionContext
-from dagster.core.errors import DagsterInvalidDefinitionError, DagsterInvariantViolationError
+from dagster.core.errors import (
+    DagsterInvalidDefinitionError,
+    ScheduleExecutionError,
+    user_code_error_boundary,
+)
 from dagster.core.storage.pipeline_run import PipelineRun, PipelineRunStatus, PipelineRunsFilter
 from dagster.core.storage.tags import check_tags
 from dagster.utils import merge_dicts
-from dagster.utils.partitions import DEFAULT_DATE_FORMAT
 
 from .mode import DEFAULT_MODE_NAME
-from .utils import check_for_invalid_name_and_warn
+from .utils import check_valid_name
 
 
 def by_name(partition):
@@ -34,41 +37,13 @@ class Partition(namedtuple("_Partition", ("value name"))):
         )
 
 
-def create_default_partition_selector_fn(delta=timedelta(days=1), fmt=DEFAULT_DATE_FORMAT):
-    check.inst_param(delta, "timedelta", (timedelta, relativedelta))
-    check.str_param(fmt, "fmt")
-
-    def inner(context, partition_set_def):
-        check.inst_param(context, "context", ScheduleExecutionContext)
-        check.inst_param(partition_set_def, "partition_set_def", PartitionSetDefinition)
-
-        if not context.scheduled_execution_time_utc:
-            return last_partition(context, partition_set_def)
-
-        # The tick at a given datetime corresponds to the time for the previous partition
-        # e.g. midnight on 12/31 is actually the 12/30 partition
-        partition_time = context.scheduled_execution_time_utc - delta
-        return Partition(value=partition_time, name=partition_time.strftime(fmt))
-
-    return inner
-
-
-def last_partition(context, partition_set_def):
-    check.inst_param(context, "context", ScheduleExecutionContext)
-    check.inst_param(partition_set_def, "partition_set_def", PartitionSetDefinition)
-
-    partitions = partition_set_def.get_partitions()
-    if not partitions:
-        return None
-    return partitions[-1]
-
-
 def last_empty_partition(context, partition_set_def):
     check.inst_param(context, "context", ScheduleExecutionContext)
     partition_set_def = check.inst_param(
         partition_set_def, "partition_set_def", PartitionSetDefinition
     )
-    partitions = partition_set_def.get_partitions()
+
+    partitions = partition_set_def.get_partitions(context.scheduled_execution_time)
     if not partitions:
         return None
     selected = None
@@ -87,7 +62,7 @@ def first_partition(context, partition_set_def=None):
         partition_set_def, "partition_set_def", PartitionSetDefinition
     )
 
-    partitions = partition_set_def.get_partitions()
+    partitions = partition_set_def.get_partitions(context.scheduled_execution_time)
     if not partitions:
         return None
 
@@ -132,7 +107,9 @@ class PartitionSetDefinition(
         run_config_fn_for_partition=lambda _partition: {},
         tags_fn_for_partition=lambda _partition: {},
     ):
-        def _wrap(x):
+        partition_fn_param_count = len(inspect.signature(partition_fn).parameters)
+
+        def _wrap_partition(x):
             if isinstance(x, Partition):
                 return x
             if isinstance(x, str):
@@ -141,13 +118,24 @@ class PartitionSetDefinition(
                 "Expected <Partition> | <str>, received {type}".format(type=type(x))
             )
 
+        def _wrap_partition_fn(current_time=None):
+            if not current_time:
+                current_time = pendulum.now("UTC")
+
+            check.callable_param(partition_fn, "partition_fn")
+
+            if partition_fn_param_count == 1:
+                obj_list = partition_fn(current_time)
+            else:
+                obj_list = partition_fn()
+
+            return [_wrap_partition(obj) for obj in obj_list]
+
         return super(PartitionSetDefinition, cls).__new__(
             cls,
-            name=check_for_invalid_name_and_warn(name),
+            name=check_valid_name(name),
             pipeline_name=check.str_param(pipeline_name, "pipeline_name"),
-            partition_fn=lambda: [
-                _wrap(x) for x in check.callable_param(partition_fn, "partition_fn")()
-            ],
+            partition_fn=_wrap_partition_fn,
             solid_selection=check.opt_nullable_list_param(
                 solid_selection, "solid_selection", of_type=str
             ),
@@ -171,8 +159,8 @@ class PartitionSetDefinition(
 
         return tags
 
-    def get_partitions(self):
-        return self.partition_fn()
+    def get_partitions(self, current_time=None):
+        return self.partition_fn(current_time)
 
     def get_partition(self, name):
         for partition in self.get_partitions():
@@ -181,28 +169,35 @@ class PartitionSetDefinition(
 
         check.failed("Partition name {} not found!".format(name))
 
-    def get_partition_names(self):
-        return [part.name for part in self.get_partitions()]
+    def get_partition_names(self, current_time=None):
+        return [part.name for part in self.get_partitions(current_time)]
 
     def create_schedule_definition(
         self,
         schedule_name,
         cron_schedule,
+        partition_selector,
         should_execute=None,
-        partition_selector=last_partition,
         environment_vars=None,
+        execution_timezone=None,
+        description=None,
     ):
         """Create a ScheduleDefinition from a PartitionSetDefinition.
 
         Arguments:
             schedule_name (str): The name of the schedule.
             cron_schedule (str): A valid cron string for the schedule
+            partition_selector (Callable[ScheduleExecutionContext, PartitionSetDefinition],
+            Partition): Function that determines the partition to use at a given execution time.
+            For time-based partition sets, will likely be either `identity_partition_selector` or a
+            selector returned by `create_offset_partition_selector`.
             should_execute (Optional[function]): Function that runs at schedule execution time that
             determines whether a schedule should execute. Defaults to a function that always returns
             ``True``.
-            partition_selector (Callable[ScheduleExecutionContext, PartitionSetDefinition],
-            Partition): A partition selector for the schedule.
             environment_vars (Optional[dict]): The environment variables to set for the schedule.
+            execution_timezone (Optional[str]): Timezone in which the schedule should run. Only works
+                with DagsterDaemonScheduler, and must be set when using that scheduler.
+            description (Optional[str]): A human-readable description of the schedule.
 
         Returns:
             ScheduleDefinition: The generated ScheduleDefinition for the partition selector
@@ -213,57 +208,74 @@ class PartitionSetDefinition(
         check.opt_callable_param(should_execute, "should_execute")
         check.opt_dict_param(environment_vars, "environment_vars", key_type=str, value_type=str)
         check.callable_param(partition_selector, "partition_selector")
+        check.opt_str_param(execution_timezone, "execution_timezone")
+        check.opt_str_param(description, "description")
 
-        def _should_execute_wrapper(context):
+        def _execution_fn(context):
             check.inst_param(context, "context", ScheduleExecutionContext)
-            selected_partition = partition_selector(context, self)
+            with user_code_error_boundary(
+                ScheduleExecutionError,
+                lambda: f"Error occurred during the execution of partition_selector for schedule {schedule_name}",
+            ):
+                selected_partition = partition_selector(context, self)
 
-            if not selected_partition or not selected_partition.name in self.get_partition_names():
-                return False
-            elif not should_execute:
-                return True
-            else:
-                return should_execute(context)
-
-        def _run_config_fn_wrapper(context):
-            check.inst_param(context, "context", ScheduleExecutionContext)
-            selected_partition = partition_selector(context, self)
             if not selected_partition:
-                raise DagsterInvariantViolationError(
-                    "The partition selection function `{selector}` did not return "
-                    "a partition from PartitionSet {partition_set}".format(
-                        selector=getattr(partition_selector, "__name__", repr(partition_selector)),
-                        partition_set=self.name,
-                    )
+                yield SkipReason(
+                    "Partition selector did not return a partition. Make sure that the timezone "
+                    "on your partition set matches your execution timezone."
                 )
+                return
 
-            return self.run_config_for_partition(selected_partition)
-
-        def _tags_fn_wrapper(context):
-            check.inst_param(context, "context", ScheduleExecutionContext)
-            selected_partition = partition_selector(context, self)
-            if not selected_partition:
-                raise DagsterInvariantViolationError(
-                    "The partition selection function `{selector}` did not return "
-                    "a partition from PartitionSet {partition_set}".format(
-                        selector=getattr(partition_selector, "__name__", repr(partition_selector)),
-                        partition_set=self.name,
-                    )
+            if selected_partition.name not in self.get_partition_names(
+                context.scheduled_execution_time
+            ):
+                yield SkipReason(
+                    f"Partition selector returned a partition {selected_partition.name} not in the partition set."
                 )
+                return
 
-            return self.tags_for_partition(selected_partition)
+            with user_code_error_boundary(
+                ScheduleExecutionError,
+                lambda: f"Error occurred during the execution of should_execute for schedule {schedule_name}",
+            ):
+                if should_execute and not should_execute(context):
+                    yield SkipReason(
+                        "should_execute function for {schedule_name} returned false.".format(
+                            schedule_name=schedule_name
+                        )
+                    )
+                    return
+
+            with user_code_error_boundary(
+                ScheduleExecutionError,
+                lambda: f"Error occurred during the execution of run_config_fn for schedule {schedule_name}",
+            ):
+                run_config = self.run_config_for_partition(selected_partition)
+
+            with user_code_error_boundary(
+                ScheduleExecutionError,
+                lambda: f"Error occurred during the execution of tags_fn for schedule {schedule_name}",
+            ):
+                tags = self.tags_for_partition(selected_partition)
+            yield RunRequest(
+                run_key=None,
+                run_config=run_config,
+                tags=tags,
+            )
 
         return PartitionScheduleDefinition(
             name=schedule_name,
             cron_schedule=cron_schedule,
             pipeline_name=self.pipeline_name,
-            run_config_fn=_run_config_fn_wrapper,
-            tags_fn=_tags_fn_wrapper,
+            tags_fn=None,
             solid_selection=self.solid_selection,
             mode=self.mode,
-            should_execute=_should_execute_wrapper,
+            should_execute=None,
             environment_vars=environment_vars,
             partition_set=self,
+            execution_timezone=execution_timezone,
+            execution_fn=_execution_fn,
+            description=description,
         )
 
 
@@ -282,9 +294,12 @@ class PartitionScheduleDefinition(ScheduleDefinition):
         environment_vars,
         partition_set,
         run_config_fn=None,
+        execution_timezone=None,
+        execution_fn=None,
+        description=None,
     ):
         super(PartitionScheduleDefinition, self).__init__(
-            name=check_for_invalid_name_and_warn(name),
+            name=check_valid_name(name),
             cron_schedule=cron_schedule,
             pipeline_name=pipeline_name,
             run_config_fn=run_config_fn,
@@ -293,6 +308,9 @@ class PartitionScheduleDefinition(ScheduleDefinition):
             mode=mode,
             should_execute=should_execute,
             environment_vars=environment_vars,
+            execution_timezone=execution_timezone,
+            execution_fn=execution_fn,
+            description=description,
         )
         self._partition_set = check.inst_param(
             partition_set, "partition_set", PartitionSetDefinition
