@@ -1,6 +1,8 @@
+import inspect
 import os
 import sys
 from collections import namedtuple
+from functools import lru_cache
 
 from dagster import check, seven
 from dagster.core.code_pointer import (
@@ -8,30 +10,35 @@ from dagster.core.code_pointer import (
     CustomPointer,
     FileCodePointer,
     ModuleCodePointer,
-    get_python_file_from_previous_stack_frame,
+    get_python_file_from_target,
 )
 from dagster.core.errors import DagsterInvalidSubsetError, DagsterInvariantViolationError
 from dagster.core.origin import PipelinePythonOrigin, RepositoryPythonOrigin, SchedulePythonOrigin
 from dagster.core.selector import parse_solid_selection
 from dagster.serdes import pack_value, unpack_value, whitelist_for_serdes
-from dagster.seven import lru_cache
 from dagster.utils.backcompat import experimental
 
-from .executable import ExecutablePipeline
+from .pipeline_base import IPipeline
 
 
 def get_ephemeral_repository_name(pipeline_name):
     check.str_param(pipeline_name, "pipeline_name")
-    return "<<pipeline:{pipeline_name}>>".format(pipeline_name=pipeline_name)
+    return "__repository__{pipeline_name}".format(pipeline_name=pipeline_name)
 
 
 @whitelist_for_serdes
-class ReconstructableRepository(namedtuple("_ReconstructableRepository", "pointer")):
+class ReconstructableRepository(
+    namedtuple("_ReconstructableRepository", "pointer container_image")
+):
     def __new__(
-        cls, pointer,
+        cls,
+        pointer,
+        container_image=None,
     ):
         return super(ReconstructableRepository, cls).__new__(
-            cls, pointer=check.inst_param(pointer, "pointer", CodePointer),
+            cls,
+            pointer=check.inst_param(pointer, "pointer", CodePointer),
+            container_image=check.opt_str_param(container_image, "container_image"),
         )
 
     @lru_cache(maxsize=1)
@@ -45,29 +52,27 @@ class ReconstructableRepository(namedtuple("_ReconstructableRepository", "pointe
         return ReconstructableSchedule(self, name)
 
     @classmethod
-    def for_file(cls, file, fn_name, working_directory=None):
+    def for_file(cls, file, fn_name, working_directory=None, container_image=None):
         if not working_directory:
             working_directory = os.getcwd()
-        return cls(FileCodePointer(file, fn_name, working_directory))
+        return cls(FileCodePointer(file, fn_name, working_directory), container_image)
 
     @classmethod
-    def for_module(cls, module, fn_name):
-        return cls(ModuleCodePointer(module, fn_name))
+    def for_module(cls, module, fn_name, container_image=None):
+        return cls(ModuleCodePointer(module, fn_name), container_image)
 
     def get_cli_args(self):
         return self.pointer.get_cli_args()
 
-    @classmethod
-    def from_legacy_repository_yaml(cls, file_path):
-        check.str_param(file_path, "file_path")
-        absolute_file_path = os.path.abspath(os.path.expanduser(file_path))
-        return cls(pointer=CodePointer.from_legacy_repository_yaml(absolute_file_path))
+    def get_python_origin(self):
+        return RepositoryPythonOrigin(
+            executable_path=sys.executable,
+            code_pointer=self.pointer,
+            container_image=self.container_image,
+        )
 
-    def get_origin(self):
-        return RepositoryPythonOrigin(executable_path=sys.executable, code_pointer=self.pointer)
-
-    def get_origin_id(self):
-        return self.get_origin().get_id()
+    def get_python_origin_id(self):
+        return self.get_python_origin().get_id()
 
 
 @whitelist_for_serdes
@@ -76,10 +81,14 @@ class ReconstructablePipeline(
         "_ReconstructablePipeline",
         "repository pipeline_name solid_selection_str solids_to_execute",
     ),
-    ExecutablePipeline,
+    IPipeline,
 ):
     def __new__(
-        cls, repository, pipeline_name, solid_selection_str=None, solids_to_execute=None,
+        cls,
+        repository,
+        pipeline_name,
+        solid_selection_str=None,
+        solids_to_execute=None,
     ):
         check.opt_set_param(solids_to_execute, "solids_to_execute", of_type=str)
         return super(ReconstructablePipeline, cls).__new__(
@@ -128,7 +137,8 @@ class ReconstructablePipeline(
             )
         else:
             pipe = ReconstructablePipeline(
-                repository=self.repository, pipeline_name=self.pipeline_name,
+                repository=self.repository,
+                pipeline_name=self.pipeline_name,
             )
 
         pipe.get_definition()  # verify the subset is correct
@@ -181,17 +191,24 @@ class ReconstructablePipeline(
         )
         return inst
 
-    def get_origin(self):
-        return PipelinePythonOrigin(self.pipeline_name, self.repository.get_origin())
+    def get_python_origin(self):
+        return PipelinePythonOrigin(self.pipeline_name, self.repository.get_python_origin())
 
-    def get_origin_id(self):
-        return self.get_origin().get_id()
+    def get_python_origin_id(self):
+        return self.get_python_origin().get_id()
 
 
 @whitelist_for_serdes
-class ReconstructableSchedule(namedtuple("_ReconstructableSchedule", "repository schedule_name",)):
+class ReconstructableSchedule(
+    namedtuple(
+        "_ReconstructableSchedule",
+        "repository schedule_name",
+    )
+):
     def __new__(
-        cls, repository, schedule_name,
+        cls,
+        repository,
+        schedule_name,
     ):
         return super(ReconstructableSchedule, cls).__new__(
             cls,
@@ -199,11 +216,11 @@ class ReconstructableSchedule(namedtuple("_ReconstructableSchedule", "repository
             schedule_name=check.str_param(schedule_name, "schedule_name"),
         )
 
-    def get_origin(self):
-        return SchedulePythonOrigin(self.schedule_name, self.repository.get_origin())
+    def get_python_origin(self):
+        return SchedulePythonOrigin(self.schedule_name, self.repository.get_python_origin())
 
-    def get_origin_id(self):
-        return self.get_origin().get_id()
+    def get_python_origin_id(self):
+        return self.get_python_origin().get_id()
 
     @lru_cache(maxsize=1)
     def get_definition(self):
@@ -212,13 +229,14 @@ class ReconstructableSchedule(namedtuple("_ReconstructableSchedule", "repository
 
 def reconstructable(target):
     """
-    Create a ReconstructablePipeline from a function that returns a PipelineDefinition, or a
-    function decorated with :py:func:`@pipeline <dagster.pipeline>`
+    Create a :py:class:`~dagster.core.definitions.reconstructable.ReconstructablePipeline` from a
+    function that returns a :py:class:`~dagster.PipelineDefinition`, or a function decorated with
+    :py:func:`@pipeline <dagster.pipeline>`
 
     When your pipeline must cross process boundaries, e.g., for execution on multiple nodes or
-    in different systems (like dagstermill), Dagster must know how to reconstruct the pipeline
+    in different systems (like ``dagstermill``), Dagster must know how to reconstruct the pipeline
     on the other side of the process boundary.
-    
+
     This function implements a very conservative strategy for reconstructing pipelines, so that
     its behavior is easy to predict, but as a consequence it is not able to reconstruct certain
     kinds of pipelines, such as those defined by lambdas, in nested scopes (e.g., dynamically
@@ -226,14 +244,14 @@ def reconstructable(target):
     notebooks.
 
     If you need to reconstruct pipelines constructed in these ways, you should use
-    :py:func:`build_reconstructable_pipeline` instead, which allows you to specify your own
-    strategy for reconstructing a pipeline.
+    :py:func:`~dagster.core.definitions.reconstructable.build_reconstructable_pipeline` instead,
+    which allows you to specify your own strategy for reconstructing a pipeline.
 
     Examples:
 
     .. code-block:: python
 
-        from dagster import PipelineDefinition, pipeline, recontructable
+        from dagster import PipelineDefinition, pipeline, reconstructable
 
         @pipeline
         def foo_pipeline():
@@ -244,7 +262,7 @@ def reconstructable(target):
 
         def make_bar_pipeline():
             return PipelineDefinition(...)
-            
+
         reconstructable_bar_pipeline = reconstructable(bar_pipeline)
     """
     from dagster.core.definitions import PipelineDefinition
@@ -272,20 +290,29 @@ def reconstructable(target):
             )
         )
 
-    python_file = get_python_file_from_previous_stack_frame()
-    if python_file.endswith("<stdin>"):
+    try:
+        if (
+            hasattr(target, "__module__")
+            and hasattr(target, "__name__")
+            and inspect.getmodule(target).__name__ != "__main__"
+        ):
+            return ReconstructablePipeline.for_module(target.__module__, target.__name__)
+    except:  # pylint: disable=bare-except
+        pass
+
+    python_file = get_python_file_from_target(target)
+    if not python_file:
         raise DagsterInvariantViolationError(
-            "reconstructable() can not reconstruct pipelines from <stdin>, unable to "
-            "target file {}. Use a pipeline defined in a module or file instead, or "
-            "use build_reconstructable_pipeline.".format(python_file)
+            "reconstructable() can not reconstruct pipelines defined in interactive environments "
+            "like <stdin>, IPython, or Jupyter notebooks. "
+            "Use a pipeline defined in a module or file instead, or "
+            "use build_reconstructable_pipeline."
         )
+
     pointer = FileCodePointer(
         python_file=python_file, fn_name=target.__name__, working_directory=os.getcwd()
     )
 
-    # ipython:
-    # Exception: Can not import module <ipython-input-3-70f55f9e97d2> from path /Users/max/Desktop/richard_brady_repro/<ipython-input-3-70f55f9e97d2>, unable to load spec.
-    # Exception: Can not import module  from path /private/var/folders/zc/zyv5jx615157j4mypwcx_kxr0000gn/T/b3edec1e-b4c5-4ea4-a4ae-24a01e566aba/, unable to load spec.
     return bootstrap_standalone_recon_pipeline(pointer)
 
 
@@ -297,20 +324,20 @@ def build_reconstructable_pipeline(
     reconstructable_kwargs=None,
 ):
     """
-    Create a ReconstructablePipeline.
+    Create a :py:class:`dagster.core.definitions.reconstructable.ReconstructablePipeline`.
 
     When your pipeline must cross process boundaries, e.g., for execution on multiple nodes or
-    in different systems (like dagstermill), Dagster must know how to reconstruct the pipeline
+    in different systems (like ``dagstermill``), Dagster must know how to reconstruct the pipeline
     on the other side of the process boundary.
-    
+
     This function allows you to use the strategy of your choice for reconstructing pipelines, so
     that you can reconstruct certain kinds of pipelines that are not supported by
-    :py:func:`reconstructable`, such as those defined by lambdas, in nested scopes (e.g.,
+    :py:func:`~dagster.reconstructable`, such as those defined by lambdas, in nested scopes (e.g.,
     dynamically within a method call), or in interactive environments such as the Python REPL or
     Jupyter notebooks.
 
     If you need to reconstruct pipelines constructed in these ways, use this function instead of
-    :py:func:`reconstructable`. 
+    :py:func:`~dagster.reconstructable`.
 
     Args:
         reconstructor_module_name (str): The name of the module containing the function to use to
@@ -330,7 +357,7 @@ def build_reconstructable_pipeline(
 
         from dagster import PipelineDefinition, pipeline, build_reconstructable_pipeline
 
-        class PipelineFactory(object):
+        class PipelineFactory:
             def make_pipeline(*args, **kwargs):
 
                 @pipeline
@@ -338,7 +365,7 @@ def build_reconstructable_pipeline(
                     ...
 
                 return _pipeline
-       
+
         def reconstruct_pipeline(*args):
             factory = PipelineFactory()
             return factory.make_pipeline(*args)
@@ -361,10 +388,10 @@ def build_reconstructable_pipeline(
     check.str_param(reconstructor_module_name, "reconstructor_module_name")
     check.str_param(reconstructor_function_name, "reconstructor_function_name")
 
-    reconstructable_args = check.opt_tuple_param(reconstructable_args, "reconstructable_args")
-    reconstructable_kwargs = tuple(
+    reconstructable_args = list(check.opt_tuple_param(reconstructable_args, "reconstructable_args"))
+    reconstructable_kwargs = list(
         (
-            (key, value)
+            [key, value]
             for key, value in check.opt_dict_param(
                 reconstructable_kwargs, "reconstructable_kwargs", key_type=str
             ).items()
@@ -425,7 +452,10 @@ def load_def_in_python_file(python_file, attribute, working_directory):
 def def_from_pointer(pointer):
     target = pointer.load_target()
 
-    if not callable(target):
+    from .pipeline import PipelineDefinition
+    from .repository import RepositoryDefinition
+
+    if isinstance(target, (PipelineDefinition, RepositoryDefinition)) or not callable(target):
         return _check_is_loadable(target)
 
     # if its a function invoke it - otherwise we are pointing to a
