@@ -1,6 +1,9 @@
+from typing import Any, Callable, Dict, Iterator, List, Set, Union
+
 from dagster import check
 from dagster.core.definitions import (
     AssetMaterialization,
+    DynamicOutput,
     ExpectationResult,
     Materialization,
     Output,
@@ -10,50 +13,46 @@ from dagster.core.definitions import (
 from dagster.core.errors import DagsterInvariantViolationError
 from dagster.core.execution.context.compute import SolidExecutionContext
 from dagster.core.execution.context.system import SystemComputeExecutionContext
+from dagster.core.system_config.objects import EnvironmentConfig
 
-from .objects import ExecutionStep, StepInput, StepKind, StepOutput
+from .outputs import StepOutput
+
+SolidOutputUnion = Union[
+    DynamicOutput, Output, AssetMaterialization, Materialization, ExpectationResult
+]
 
 
-def create_compute_step(pipeline_name, environment_config, solid, step_inputs, handle):
-    check.str_param(pipeline_name, "pipeline_name")
+def create_step_outputs(
+    solid: Solid, handle: SolidHandle, environment_config: EnvironmentConfig
+) -> List[StepOutput]:
     check.inst_param(solid, "solid", Solid)
-    check.list_param(step_inputs, "step_inputs", of_type=StepInput)
-    check.opt_inst_param(handle, "handle", SolidHandle)
+    check.inst_param(handle, "handle", SolidHandle)
 
     # the environment config has the solid output name configured
-    config_output_names = set()
+    config_output_names: Set[str] = set()
     current_handle = handle
     while current_handle:
         solid_config = environment_config.solids.get(current_handle.to_string())
         current_handle = current_handle.parent
-        for output_spec in solid_config.outputs:
-            config_output_names = config_output_names.union(output_spec.keys())
+        config_output_names = config_output_names.union(solid_config.outputs.output_names)
 
-    return ExecutionStep(
-        pipeline_name=pipeline_name,
-        key_suffix="compute",
-        step_inputs=step_inputs,
-        step_outputs=[
-            StepOutput(
-                name=name,
-                dagster_type=output_def.dagster_type,
-                optional=output_def.optional,
-                should_materialize=name in config_output_names,
-            )
-            for name, output_def in solid.definition.output_dict.items()
-        ],
-        compute_fn=lambda step_context, inputs: _execute_core_compute(
-            step_context.for_compute(), inputs, solid.definition.compute_fn
-        ),
-        kind=StepKind.COMPUTE,
-        solid_handle=handle,
-        solid=solid,
-        tags=solid.tags,
-        hook_defs=solid.hook_defs,
-    )
+    return [
+        StepOutput(
+            solid_handle=handle,
+            name=output_def.name,
+            dagster_type_key=output_def.dagster_type.key,
+            is_required=output_def.is_required,
+            is_dynamic=output_def.is_dynamic,
+            is_asset=output_def.is_asset,
+            should_materialize=output_def.name in config_output_names,
+        )
+        for name, output_def in solid.definition.output_dict.items()
+    ]
 
 
-def _yield_compute_results(compute_context, inputs, compute_fn):
+def _yield_compute_results(
+    compute_context: SystemComputeExecutionContext, inputs: Dict[str, Any], compute_fn: Callable
+) -> Iterator[SolidOutputUnion]:
     check.inst_param(compute_context, "compute_context", SystemComputeExecutionContext)
     step = compute_context.step
     user_event_sequence = compute_fn(SolidExecutionContext(compute_context), inputs)
@@ -71,7 +70,10 @@ def _yield_compute_results(compute_context, inputs, compute_fn):
         return
 
     for event in user_event_sequence:
-        if isinstance(event, (Output, AssetMaterialization, Materialization, ExpectationResult)):
+        if isinstance(
+            event,
+            (DynamicOutput, Output, AssetMaterialization, Materialization, ExpectationResult),
+        ):
             yield event
         else:
             raise DagsterInvariantViolationError(
@@ -88,7 +90,9 @@ def _yield_compute_results(compute_context, inputs, compute_fn):
             )
 
 
-def _execute_core_compute(compute_context, inputs, compute_fn):
+def execute_core_compute(
+    compute_context: SystemComputeExecutionContext, inputs: Dict[str, Any], compute_fn
+) -> Iterator[SolidOutputUnion]:
     """
     Execute the user-specified compute for the solid. Wrap in an error boundary and do
     all relevant logging and metrics tracking
@@ -101,13 +105,13 @@ def _execute_core_compute(compute_context, inputs, compute_fn):
     all_results = []
     for step_output in _yield_compute_results(compute_context, inputs, compute_fn):
         yield step_output
-        if isinstance(step_output, Output):
+        if isinstance(step_output, (DynamicOutput, Output)):
             all_results.append(step_output)
 
-    if len(all_results) != len(step.step_outputs):
-        emitted_result_names = {r.output_name for r in all_results}
-        solid_output_names = {output.name for output in step.step_outputs}
-        omitted_outputs = solid_output_names.difference(emitted_result_names)
+    emitted_result_names = {r.output_name for r in all_results}
+    solid_output_names = {output.name for output in step.step_outputs}
+    omitted_outputs = solid_output_names.difference(emitted_result_names)
+    if omitted_outputs:
         compute_context.log.info(
             "Solid {solid} did not fire outputs {outputs}".format(
                 solid=str(step.solid_handle), outputs=repr(omitted_outputs)
