@@ -1,5 +1,5 @@
 """As an open source project, we collect usage statistics to inform development priorities.
-For more information, check out the docs at https://docs.dagster.io/install/telemetry/'
+For more information, check out the docs at https://docs.dagster.io/install#telemetry'
 
 To see the logs we send, inspect $DAGSTER_HOME/logs/ if $DAGSTER_HOME is set or ~/.dagster/logs/
 
@@ -23,10 +23,7 @@ from functools import wraps
 from logging.handlers import RotatingFileHandler
 
 import click
-import requests
-import six
 import yaml
-
 from dagster import check
 from dagster.core.definitions.pipeline_base import IPipeline
 from dagster.core.definitions.reconstructable import (
@@ -49,7 +46,7 @@ TELEMETRY_VERSION = "0.2"
 
 # start_TELEMETRY_WHITELISTED_FUNCTIONS
 TELEMETRY_WHITELISTED_FUNCTIONS = {
-    "_launch_scheduled_execution",
+    "_launch_scheduled_executions",
     "_logged_execute_pipeline",
     "execute_execute_command",
     "execute_launch_command",
@@ -266,6 +263,18 @@ def _get_telemetry_logger():
     return logger
 
 
+# For use in test teardown
+def cleanup_telemetry_logger():
+    logger = logging.getLogger("dagster_telemetry_logger")
+    if len(logger.handlers) == 0:
+        return
+
+    check.invariant(len(logger.handlers) == 1)
+    handler = next(iter(logger.handlers))
+    handler.close()
+    logger.removeHandler(handler)
+
+
 def write_telemetry_log_line(log_line):
     logger = _get_telemetry_logger()
     logger.info(json.dumps(log_line))
@@ -300,7 +309,7 @@ def _get_telemetry_instance_id():
     with open(telemetry_id_path, "r") as telemetry_id_file:
         telemetry_id_yaml = yaml.safe_load(telemetry_id_file)
         if INSTANCE_ID_STR in telemetry_id_yaml and isinstance(
-            telemetry_id_yaml[INSTANCE_ID_STR], six.string_types
+            telemetry_id_yaml[INSTANCE_ID_STR], str
         ):
             return telemetry_id_yaml[INSTANCE_ID_STR]
     return None
@@ -396,6 +405,19 @@ def log_repo_stats(instance, source, pipeline=None, repo=None):
         )
 
 
+def log_workspace_stats(instance, workspace_process_context):
+    from dagster.cli.workspace import WorkspaceProcessContext
+
+    check.inst_param(instance, "instance", DagsterInstance)
+    check.inst_param(
+        workspace_process_context, "workspace_process_context", WorkspaceProcessContext
+    )
+
+    for repo_location in workspace_process_context.repository_locations:
+        for external_repo in repo_location.get_repositories().values():
+            log_external_repo_stats(instance, source="dagit", external_repo=external_repo)
+
+
 def log_action(instance, action, client_time=None, elapsed_time=None, metadata=None):
     check.inst_param(instance, "instance", DagsterInstance)
     if client_time is None:
@@ -421,7 +443,7 @@ TELEMETRY_TEXT = """
   %(telemetry)s
 
   As an open source project, we collect usage statistics to inform development priorities. For more
-  information, read https://docs.dagster.io/install/telemetry.
+  information, read https://docs.dagster.io/install#telemetry.
 
   We will not see or store solid definitions, pipeline definitions, modes, resources, context, or
   any data that is processed within solids and pipelines.
@@ -444,8 +466,23 @@ SLACK_PROMPT = """
 }
 
 
-def upload_logs(stop_event):
+def is_running_in_test():
+    return (
+        os.getenv("BUILDKITE") is not None
+        or os.getenv("TF_BUILD") is not None
+        or os.getenv("DAGSTER_DISABLE_TELEMETRY") is not None
+    )
+
+
+def upload_logs(stop_event, raise_errors=False):
     """Upload logs to telemetry server every hour, or when log directory size is > 10MB"""
+
+    # We add a sanity check to ensure that no logs are uploaded in our
+    # buildkite/azure testing pipelines. The check is present at upload to
+    # allow for testing of logs being correctly written.
+    if is_running_in_test():
+        return
+
     try:
         last_run = datetime.datetime.now() - datetime.timedelta(minutes=120)
         dagster_log_dir = get_dir_from_dagster_home("logs")
@@ -480,17 +517,24 @@ def upload_logs(stop_event):
                 last_run = datetime.datetime.now()
                 dagster_log_dir = get_dir_from_dagster_home("logs")
                 dagster_log_queue_dir = get_dir_from_dagster_home(".logs_queue")
-                _upload_logs(dagster_log_dir, log_size, dagster_log_queue_dir)
+                _upload_logs(
+                    dagster_log_dir, log_size, dagster_log_queue_dir, raise_errors=raise_errors
+                )
                 in_progress = False
 
             stop_event.wait(600)  # Sleep for 10 minutes
     except Exception:  # pylint: disable=broad-except
-        pass
+        if raise_errors:
+            raise
 
 
-def _upload_logs(dagster_log_dir, log_size, dagster_log_queue_dir):
+def _upload_logs(dagster_log_dir, log_size, dagster_log_queue_dir, raise_errors):
     """Send POST request to telemetry server with the contents of $DAGSTER_HOME/logs/ directory """
+
     try:
+        # lazy import for perf
+        import requests
+
         if log_size > 0:
             # Delete contents of dagster_log_queue_dir so that new logs can be copied over
             for f in os.listdir(dagster_log_queue_dir):
@@ -498,6 +542,8 @@ def _upload_logs(dagster_log_dir, log_size, dagster_log_queue_dir):
                 # too much complexity...
                 os.remove(os.path.join(dagster_log_queue_dir, f))
 
+            os.rmdir(dagster_log_queue_dir)
+
             os.rename(dagster_log_dir, dagster_log_queue_dir)
 
         for curr_path in os.listdir(dagster_log_queue_dir):
@@ -521,4 +567,5 @@ def _upload_logs(dagster_log_dir, log_size, dagster_log_queue_dir):
                 os.remove(curr_full_path)
 
     except Exception:  # pylint: disable=broad-except
-        pass
+        if raise_errors:
+            raise
