@@ -1,23 +1,35 @@
 import hashlib
 
 from dagster import check
-from dagster.config.config_type import ConfigType, ConfigTypeKind
+from dagster.config.config_type import ConfigType
 from dagster.core.decorator_utils import (
     split_function_parameters,
     validate_decorated_fn_positionals,
 )
 from dagster.core.errors import DagsterInvalidDefinitionError
-from dagster.utils import ensure_gen, ensure_single_item
-from dagster.utils.backcompat import canonicalize_backcompat_args, rename_warning
+from dagster.utils import ensure_gen
+from dagster.utils.backcompat import experimental_arg_warning
 
 
-class DagsterTypeLoader(object):
+class DagsterTypeLoader:
+    """
+    Dagster type loaders are used to load unconnected inputs of the dagster type they are attached
+    to.
+
+    The recommended way to define a type loader is with the
+    :py:func:`@dagster_type_loader <dagster_type_loader>` decorator.
+    """
+
     @property
     def schema_type(self):
         check.not_implemented(
             "Must override schema_type in {klass}".format(klass=type(self).__name__)
         )
 
+    @property
+    def loader_version(self):
+        return None
+
     def compute_loaded_input_version(self, _config_value):
         return None
 
@@ -31,13 +43,15 @@ class DagsterTypeLoader(object):
         return frozenset()
 
 
-class InputHydrationConfig(DagsterTypeLoader):
-    def __init__(self):
-        rename_warning("DagsterTypeLoader", "InputHydrationConfig", "0.10.0")
-        super(InputHydrationConfig, self).__init__()
+class DagsterTypeMaterializer:
+    """
+    Dagster type materializers are used to materialize outputs of the dagster type they are attached
+    to.
 
+    The recommended way to define a type loader is with the
+    :py:func:`@dagster_type_materializer <dagster_type_materializer>` decorator.
+    """
 
-class DagsterTypeMaterializer(object):
     @property
     def schema_type(self):
         check.not_implemented(
@@ -54,12 +68,6 @@ class DagsterTypeMaterializer(object):
         return frozenset()
 
 
-class OutputMaterializationConfig(DagsterTypeMaterializer):
-    def __init__(self):
-        rename_warning("DagsterTypeMaterializer", "OutputMaterializationConfig", "0.10.0")
-        super(OutputMaterializationConfig, self).__init__()
-
-
 class DagsterTypeLoaderFromDecorator(DagsterTypeLoader):
     def __init__(
         self,
@@ -67,28 +75,53 @@ class DagsterTypeLoaderFromDecorator(DagsterTypeLoader):
         func,
         required_resource_keys,
         loader_version=None,
-        external_version_fn=lambda: None,
+        external_version_fn=None,
     ):
         self._config_type = check.inst_param(config_type, "config_type", ConfigType)
         self._func = check.callable_param(func, "func")
         self._required_resource_keys = check.opt_set_param(
             required_resource_keys, "required_resource_keys", of_type=str
         )
-        self._loader_version = loader_version
-        self._external_version_fn = external_version_fn
+        self._loader_version = check.opt_str_param(loader_version, "loader_version")
+        if self._loader_version:
+            experimental_arg_warning("loader_version", "DagsterTypeLoaderFromDecorator.__init__")
+        self._external_version_fn = check.opt_callable_param(
+            external_version_fn, "external_version_fn"
+        )
+        if self._external_version_fn:
+            experimental_arg_warning(
+                "external_version_fn", "DagsterTypeLoaderFromDecorator.__init__"
+            )
 
     @property
     def schema_type(self):
         return self._config_type
 
+    @property
+    def loader_version(self):
+        return self._loader_version
+
     def compute_loaded_input_version(self, config_value):
+        """Compute the type-loaded input from a given config_value.
+
+        Args:
+            config_value (Union[Any, Dict]): Config value to be ingested by the external version
+                loading function.
+        Returns:
+            Optional[str]: Hash of concatenated loader version and external input version if both
+                are provided, else None.
+        """
         version = ""
-        if self._loader_version:
-            version += str(self._loader_version)
-        ext_version = self._external_version_fn(config_value)
-        if ext_version:
+        if self.loader_version:
+            version += str(self.loader_version)
+        if self._external_version_fn:
+            ext_version = self._external_version_fn(config_value)
             version += str(ext_version)
-        return hashlib.sha1(version).hexdigest()
+
+        if version == "":
+            return None  # Sentinel value for no version provided.
+        else:
+            return hashlib.sha1(version.encode("utf-8")).hexdigest()
 
     def construct_from_config_value(self, context, config_value):
         return self._func(context, config_value)
@@ -98,27 +131,22 @@ class DagsterTypeLoaderFromDecorator(DagsterTypeLoader):
 
 
 def _create_type_loader_for_decorator(
-    config_type, func, required_resource_keys, loader_version=None, external_version_fn=lambda: None
+    config_type,
+    func,
+    required_resource_keys,
+    loader_version=None,
+    external_version_fn=None,
 ):
     return DagsterTypeLoaderFromDecorator(
         config_type, func, required_resource_keys, loader_version, external_version_fn
     )
 
 
-def input_hydration_config(config_schema=None, required_resource_keys=None, config_cls=None):
-    """Deprecated in favor of dagster_type_loader"""
-    rename_warning("dagster_type_loader", "input_hydration_config", "0.10.0")
-    config_schema = canonicalize_backcompat_args(
-        config_schema, "config_schema", config_cls, "config_cls", "0.10.0",
-    )
-    return dagster_type_loader(config_schema, required_resource_keys)
-
-
 def dagster_type_loader(
     config_schema,
     required_resource_keys=None,
     loader_version=None,
-    external_version_fn=lambda: None,
+    external_version_fn=None,
 ):
     """Create an dagster type loader that maps config data to a runtime value.
 
@@ -131,7 +159,7 @@ def dagster_type_loader(
         loader_version (str): (Experimental) The version of the decorated compute function. Two
             loading functions should have the same version if and only if they deterministically
             produce the same outputs when provided the same inputs.
-        external_version_fn (Callable): A function that takes in the same parameters as the loader
+        external_version_fn (Callable): (Experimental) A function that takes in the same parameters as the loader
             function (config_value) and returns a representation of the version of the external
             asset (str). Two external assets with identical versions are treated as identical to one
             another.
@@ -167,32 +195,6 @@ def dagster_type_loader(
     return wrapper
 
 
-def input_selector_schema(config_cls, required_resource_keys=None):
-    """
-    Deprecated in favor of dagster_type_loader.
-
-    A decorator for annotating a function that can take the selected properties
-    from a ``config_value`` in to an instance of a custom type.
-
-    Args:
-        config_cls (Selector)
-    """
-    rename_warning("dagster_type_loader", "input_selector_schema", "0.10.0")
-    from dagster.config.field import resolve_to_config_type
-
-    config_type = resolve_to_config_type(config_cls)
-    check.param_invariant(config_type.kind == ConfigTypeKind.SELECTOR, "config_cls")
-
-    def _wrap(func):
-        def _selector(context, config_value):
-            selector_key, selector_value = ensure_single_item(config_value)
-            return func(context, selector_key, selector_value)
-
-        return _create_type_loader_for_decorator(config_type, _selector, required_resource_keys)
-
-    return _wrap
-
-
 class DagsterTypeMaterializerForDecorator(DagsterTypeMaterializer):
     def __init__(self, config_type, func, required_resource_keys):
         self._config_type = check.inst_param(config_type, "config_type", ConfigType)
@@ -216,15 +218,6 @@ def _create_output_materializer_for_decorator(config_type, func, required_resour
     return DagsterTypeMaterializerForDecorator(config_type, func, required_resource_keys)
 
 
-def output_materialization_config(config_schema=None, required_resource_keys=None, config_cls=None):
-    """Deprecated in favor of dagster_type_materializer"""
-    rename_warning("dagster_type_materializer", "output_materialization_config", "0.10.0")
-    config_schema = canonicalize_backcompat_args(
-        config_schema, "config_schema", config_cls, "config_cls", "0.10.0",
-    )
-    return dagster_type_materializer(config_schema, required_resource_keys)
-
-
 def dagster_type_materializer(config_schema, required_resource_keys=None):
     """Create an output materialization hydration config that configurably materializes a runtime
     value.
@@ -258,31 +251,3 @@ def dagster_type_materializer(config_schema, required_resource_keys=None):
     return lambda func: _create_output_materializer_for_decorator(
         config_type, func, required_resource_keys
     )
-
-
-def output_selector_schema(config_cls, required_resource_keys=None):
-    """
-    Deprecated in favor of dagster_type_materializer.
-
-    A decorator for a annotating a function that can take the selected properties
-    of a ``config_value`` and an instance of a custom type and materialize it.
-
-    Args:
-        config_cls (Selector):
-    """
-    rename_warning("dagster_type_materializer", "output_selector_schema", "0.10.0")
-    from dagster.config.field import resolve_to_config_type
-
-    config_type = resolve_to_config_type(config_cls)
-    check.param_invariant(config_type.kind == ConfigTypeKind.SELECTOR, "config_cls")
-
-    def _wrap(func):
-        def _selector(context, config_value, runtime_value):
-            selector_key, selector_value = ensure_single_item(config_value)
-            return func(context, selector_key, selector_value, runtime_value)
-
-        return _create_output_materializer_for_decorator(
-            config_type, _selector, required_resource_keys
-        )
-
-    return _wrap
