@@ -5,28 +5,29 @@ import warnings
 from contextlib import contextmanager
 
 import grpc
-
 from dagster import check, seven
 from dagster.core.events import EngineEventData
+from dagster.core.host_representation import ExternalRepositoryOrigin
 from dagster.core.instance import DagsterInstance
-from dagster.core.origin import RepositoryGrpcServerOrigin
 from dagster.core.types.loadable_target_origin import LoadableTargetOrigin
 from dagster.serdes import deserialize_json_to_dagster_namedtuple, serialize_dagster_namedtuple
 from dagster.utils.error import serializable_error_info_from_exc_info
+from grpc_health.v1 import health_pb2
+from grpc_health.v1.health_pb2_grpc import HealthStub
 
 from .__generated__ import DagsterApiStub, api_pb2
 from .server import GrpcServerProcess
 from .types import (
     CanCancelExecutionRequest,
     CancelExecutionRequest,
-    ExecuteRunArgs,
+    ExecuteExternalPipelineArgs,
     ExecutionPlanSnapshotArgs,
     ExternalScheduleExecutionArgs,
-    ExternalTriggeredExecutionArgs,
     PartitionArgs,
     PartitionNamesArgs,
     PartitionSetExecutionParamArgs,
     PipelineSubsetSnapshotArgs,
+    SensorExecutionArgs,
 )
 
 CLIENT_HEARTBEAT_INTERVAL = 1
@@ -44,11 +45,15 @@ def client_heartbeat_thread(client, shutdown_event):
             continue
 
 
-class DagsterGrpcClient(object):
-    def __init__(self, port=None, socket=None, host="localhost"):
+class DagsterGrpcClient:
+    def __init__(self, port=None, socket=None, host="localhost", use_ssl=False):
         self.port = check.opt_int_param(port, "port")
         self.socket = check.opt_str_param(socket, "socket")
         self.host = check.opt_str_param(host, "host")
+        self._use_ssl = check.bool_param(use_ssl, "use_ssl")
+
+        self._ssl_creds = grpc.ssl_channel_credentials() if use_ssl else None
+
         check.invariant(
             port is not None if seven.IS_WINDOWS else True,
             "You must pass a valid `port` on Windows: `socket` not supported.",
@@ -58,7 +63,8 @@ class DagsterGrpcClient(object):
             "You must pass one and only one of `port` or `socket`.",
         )
         check.invariant(
-            host is not None if port else True, "Must provide a hostname",
+            host is not None if port else True,
+            "Must provide a hostname",
         )
 
         if port:
@@ -66,19 +72,27 @@ class DagsterGrpcClient(object):
         else:
             self._server_address = "unix:" + os.path.abspath(socket)
 
-    def _query(self, method, request_type, **kwargs):
-        with grpc.insecure_channel(self._server_address) as channel:
+    @contextmanager
+    def _channel(self):
+        with (
+            grpc.secure_channel(self._server_address, self._ssl_creds)
+            if self._use_ssl
+            else grpc.insecure_channel(self._server_address)
+        ) as channel:
+            yield channel
+
+    def _query(self, method, request_type, timeout=None, **kwargs):
+        with self._channel() as channel:
             stub = DagsterApiStub(channel)
-            response = getattr(stub, method)(request_type(**kwargs))
+            response = getattr(stub, method)(request_type(**kwargs), timeout=timeout)
         # TODO need error handling here
         return response
 
     def _streaming_query(self, method, request_type, **kwargs):
-        with grpc.insecure_channel(self._server_address) as channel:
+        with self._channel() as channel:
             stub = DagsterApiStub(channel)
             response_stream = getattr(stub, method)(request_type(**kwargs))
-            for response in response_stream:
-                yield response
+            yield from response_stream
 
     def ping(self, echo):
         check.str_param(echo, "echo")
@@ -105,6 +119,10 @@ class DagsterGrpcClient(object):
                 "echo": res.echo,
             }
 
+    def get_server_id(self, timeout=None):
+        res = self._query("GetServerId", api_pb2.Empty, timeout=timeout)
+        return res.server_id
+
     def execution_plan_snapshot(self, execution_plan_snapshot_args):
         check.inst_param(
             execution_plan_snapshot_args, "execution_plan_snapshot_args", ExecutionPlanSnapshotArgs
@@ -203,23 +221,38 @@ class DagsterGrpcClient(object):
             res.serialized_external_pipeline_subset_result
         )
 
-    def external_repository(self, repository_grpc_server_origin):
+    def external_repository(self, external_repository_origin):
         check.inst_param(
-            repository_grpc_server_origin,
-            "repository_grpc_server_origin",
-            RepositoryGrpcServerOrigin,
+            external_repository_origin,
+            "external_repository_origin",
+            ExternalRepositoryOrigin,
         )
 
         res = self._query(
             "ExternalRepository",
             api_pb2.ExternalRepositoryRequest,
+            # rename this param name
             serialized_repository_python_origin=serialize_dagster_namedtuple(
-                repository_grpc_server_origin
+                external_repository_origin
             ),
         )
 
         return deserialize_json_to_dagster_namedtuple(res.serialized_external_repository_data)
 
+    def streaming_external_repository(self, external_repository_origin):
+        for res in self._streaming_query(
+            "StreamingExternalRepository",
+            api_pb2.ExternalRepositoryRequest,
+            # Rename parameter
+            serialized_repository_python_origin=serialize_dagster_namedtuple(
+                external_repository_origin
+            ),
+        ):
+            yield {
+                "sequence_number": res.sequence_number,
+                "serialized_external_repository_chunk": res.serialized_external_repository_chunk,
+            }
+
     def external_schedule_execution(self, external_schedule_execution_args):
         check.inst_param(
             external_schedule_execution_args,
@@ -239,97 +272,34 @@ class DagsterGrpcClient(object):
             res.serialized_external_schedule_execution_data_or_external_schedule_execution_error
         )
 
-    def external_trigger_execution_params(self, external_triggered_execution_args):
+    def external_sensor_execution(self, sensor_execution_args):
         check.inst_param(
-            external_triggered_execution_args,
-            "external_triggered_execution_args",
-            ExternalTriggeredExecutionArgs,
+            sensor_execution_args,
+            "sensor_execution_args",
+            SensorExecutionArgs,
         )
 
         res = self._query(
-            "ExternalTriggerExecutionParams",
-            api_pb2.ExternalTriggerExecutionParamsRequest,
-            serialized_external_triggered_execution_args=serialize_dagster_namedtuple(
-                external_triggered_execution_args
+            "ExternalSensorExecution",
+            api_pb2.ExternalSensorExecutionRequest,
+            serialized_external_sensor_execution_args=serialize_dagster_namedtuple(
+                sensor_execution_args
             ),
         )
 
         return deserialize_json_to_dagster_namedtuple(
-            res.serialized_external_execution_params_or_external_execution_params_error_data
+            res.serialized_external_sensor_execution_data_or_external_sensor_execution_error
         )
 
-    def execute_run(self, execute_run_args):
-        check.inst_param(execute_run_args, "execute_run_args", ExecuteRunArgs)
-
-        try:
-            instance = DagsterInstance.from_ref(execute_run_args.instance_ref)
-            pipeline_run = instance.get_run_by_id(execute_run_args.pipeline_run_id)
-            event_iterator = self._streaming_query(
-                "ExecuteRun",
-                api_pb2.ExecuteRunRequest,
-                serialized_execute_run_args=serialize_dagster_namedtuple(execute_run_args),
-            )
-        except Exception as exc:  # pylint: disable=bare-except
-            yield instance.report_engine_event(
-                message="Unexpected error in IPC client",
-                pipeline_run=pipeline_run,
-                engine_event_data=EngineEventData.engine_error(
-                    serializable_error_info_from_exc_info(sys.exc_info())
-                ),
-            )
-            raise exc
-
-        try:
-            for event in event_iterator:
-                yield deserialize_json_to_dagster_namedtuple(
-                    event.serialized_dagster_event_or_ipc_error_message
-                )
-        except KeyboardInterrupt:
-            self.cancel_execution(CancelExecutionRequest(run_id=execute_run_args.pipeline_run_id))
-            raise
-        except grpc.RpcError as rpc_error:
-            if (
-                # posix
-                "Socket closed" in rpc_error.debug_error_string()  # pylint: disable=no-member
-                # windows
-                or "Stream removed" in rpc_error.debug_error_string()  # pylint: disable=no-member
-            ):
-                yield instance.report_engine_event(
-                    message="User process: GRPC server for {run_id} terminated unexpectedly".format(
-                        run_id=pipeline_run.run_id
-                    ),
-                    pipeline_run=pipeline_run,
-                    engine_event_data=EngineEventData.engine_error(
-                        serializable_error_info_from_exc_info(sys.exc_info())
-                    ),
-                )
-                yield instance.report_run_failed(pipeline_run)
-            else:
-                yield instance.report_engine_event(
-                    message="Unexpected error in IPC client",
-                    pipeline_run=pipeline_run,
-                    engine_event_data=EngineEventData.engine_error(
-                        serializable_error_info_from_exc_info(sys.exc_info())
-                    ),
-                )
-            raise rpc_error
-        except Exception as exc:  # pylint: disable=bare-except
-            yield instance.report_engine_event(
-                message="Unexpected error in IPC client",
-                pipeline_run=pipeline_run,
-                engine_event_data=EngineEventData.engine_error(
-                    serializable_error_info_from_exc_info(sys.exc_info())
-                ),
-            )
-            raise exc
-
-    def shutdown_server(self):
-        res = self._query("ShutdownServer", api_pb2.Empty)
+    def shutdown_server(self, timeout=15):
+        res = self._query("ShutdownServer", api_pb2.Empty, timeout=timeout)
         return deserialize_json_to_dagster_namedtuple(res.serialized_shutdown_server_result)
 
     def cancel_execution(self, cancel_execution_request):
         check.inst_param(
-            cancel_execution_request, "cancel_execution_request", CancelExecutionRequest,
+            cancel_execution_request,
+            "cancel_execution_request",
+            CancelExecutionRequest,
         )
 
         res = self._query(
@@ -342,14 +312,17 @@ class DagsterGrpcClient(object):
 
         return deserialize_json_to_dagster_namedtuple(res.serialized_cancel_execution_result)
 
-    def can_cancel_execution(self, can_cancel_execution_request):
+    def can_cancel_execution(self, can_cancel_execution_request, timeout=None):
         check.inst_param(
-            can_cancel_execution_request, "can_cancel_execution_request", CanCancelExecutionRequest,
+            can_cancel_execution_request,
+            "can_cancel_execution_request",
+            CanCancelExecutionRequest,
         )
 
         res = self._query(
             "CanCancelExecution",
             api_pb2.CanCancelExecutionRequest,
+            timeout=timeout,
             serialized_can_cancel_execution_request=serialize_dagster_namedtuple(
                 can_cancel_execution_request
             ),
@@ -358,32 +331,46 @@ class DagsterGrpcClient(object):
         return deserialize_json_to_dagster_namedtuple(res.serialized_can_cancel_execution_result)
 
     def start_run(self, execute_run_args):
-        check.inst_param(execute_run_args, "execute_run_args", ExecuteRunArgs)
+        check.inst_param(execute_run_args, "execute_run_args", ExecuteExternalPipelineArgs)
 
-        try:
-            instance = DagsterInstance.from_ref(execute_run_args.instance_ref)
-            pipeline_run = instance.get_run_by_id(execute_run_args.pipeline_run_id)
-            res = self._query(
-                "StartRun",
-                api_pb2.StartRunRequest,
-                serialized_execute_run_args=serialize_dagster_namedtuple(execute_run_args),
-            )
-            return deserialize_json_to_dagster_namedtuple(res.serialized_start_run_result)
+        with DagsterInstance.from_ref(execute_run_args.instance_ref) as instance:
+            try:
+                res = self._query(
+                    "StartRun",
+                    api_pb2.StartRunRequest,
+                    serialized_execute_run_args=serialize_dagster_namedtuple(execute_run_args),
+                )
+                return deserialize_json_to_dagster_namedtuple(res.serialized_start_run_result)
 
-        except Exception:  # pylint: disable=bare-except
-            instance.report_engine_event(
-                message="Unexpected error in IPC client",
-                pipeline_run=pipeline_run,
-                engine_event_data=EngineEventData.engine_error(
-                    serializable_error_info_from_exc_info(sys.exc_info())
-                ),
-            )
-            raise
+            except Exception:  # pylint: disable=bare-except
+                pipeline_run = instance.get_run_by_id(execute_run_args.pipeline_run_id)
+                instance.report_engine_event(
+                    message="Unexpected error in IPC client",
+                    pipeline_run=pipeline_run,
+                    engine_event_data=EngineEventData.engine_error(
+                        serializable_error_info_from_exc_info(sys.exc_info())
+                    ),
+                )
+                raise
 
     def get_current_image(self):
         res = self._query("GetCurrentImage", api_pb2.Empty)
         return deserialize_json_to_dagster_namedtuple(res.serialized_current_image)
 
+    def health_check_query(self):
+        try:
+            with grpc.insecure_channel(self._server_address) as channel:
+                response = HealthStub(channel).Check(
+                    health_pb2.HealthCheckRequest(service="DagsterApi")
+                )
+        except grpc.RpcError as e:
+            print(e)  # pylint: disable=print-call
+            return health_pb2.HealthCheckResponse.UNKNOWN  # pylint: disable=no-member
+
+        status_number = response.status
+        # pylint: disable=no-member
+        return health_pb2.HealthCheckResponse.ServingStatus.Name(status_number)
+
 
 class EphemeralDagsterGrpcClient(DagsterGrpcClient):
     """A client that tells the server process that created it to shut down once it leaves a
@@ -421,7 +408,7 @@ class EphemeralDagsterGrpcClient(DagsterGrpcClient):
 
 @contextmanager
 def ephemeral_grpc_api_client(
-    loadable_target_origin=None, force_port=False, max_retries=10, max_workers=1
+    loadable_target_origin=None, force_port=False, max_retries=10, max_workers=None
 ):
     check.opt_inst_param(loadable_target_origin, "loadable_target_origin", LoadableTargetOrigin)
     check.bool_param(force_port, "force_port")
@@ -432,5 +419,6 @@ def ephemeral_grpc_api_client(
         force_port=force_port,
         max_retries=max_retries,
         max_workers=max_workers,
+        lazy_load_user_code=True,
     ).create_ephemeral_client() as client:
         yield client
