@@ -13,18 +13,17 @@ import tempfile
 import threading
 from collections import namedtuple
 from enum import Enum
+from typing import Iterator
 from warnings import warn
 
-import six
+import _thread as thread
 import yaml
-from six.moves import configparser
-
 from dagster import check, seven
-from dagster.core.errors import DagsterInvariantViolationError
-from dagster.seven import IS_WINDOWS, TemporaryDirectory, multiprocessing, thread
+from dagster.core.errors import DagsterExecutionInterruptedError, DagsterInvariantViolationError
+from dagster.seven import IS_WINDOWS, multiprocessing
 from dagster.seven.abc import Mapping
-from dagster.utils.merger import merge_dicts
 
+from .merger import merge_dicts
 from .yaml_utils import load_yaml_from_glob_list, load_yaml_from_globs, load_yaml_from_path
 
 if sys.version_info > (3,):
@@ -34,24 +33,28 @@ else:
 
 EPOCH = datetime.datetime.utcfromtimestamp(0)
 
-# 2/3 compatibility
-PICKLE_PROTOCOL = 2
+PICKLE_PROTOCOL = 4
 
 
-DEFAULT_REPOSITORY_YAML_FILENAME = "repository.yaml"
 DEFAULT_WORKSPACE_YAML_FILENAME = "workspace.yaml"
 
 
-def file_relative_path(dunderfile, relative_path):
-    """
-    This function is useful when one needs to load a file that is
-    relative to the position of the current file. (Such as when
-    you encode a configuration file path in source file and want
+def file_relative_path(dunderfile: str, relative_path: str) -> str:
+    """Get a path relative to the currently executing Python file.
+
+    This function is useful when one needs to load a file that is relative to the position of
+    the current file. (Such as when you encode a configuration file path in source file and want
     in runnable in any current working directory)
 
-    It is meant to be used like the following:
+    Args:
+        dunderfile (str): Should always be ``__file__``.
+        relative_path (str): Path to get relative to the currently executing file.
 
-    file_relative_path(__file__, 'path/relative/to/file')
+    **Examples**:
+
+    .. code-block:: python
+
+        file_relative_path(__file__, 'path/relative/to/file')
 
     """
 
@@ -61,7 +64,7 @@ def file_relative_path(dunderfile, relative_path):
     return os.path.join(os.path.dirname(dunderfile), relative_path)
 
 
-def script_relative_path(file_path):
+def script_relative_path(file_path: str) -> str:
     """
     Useful for testing with local files. Use a path relative to where the
     test resides and this function will return the absolute path
@@ -110,7 +113,7 @@ def pushd(path):
 
 
 def safe_isfile(path):
-    """"Backport of Python 3.8 os.path.isfile behavior.
+    """ "Backport of Python 3.8 os.path.isfile behavior.
 
     This is intended to backport https://docs.python.org/dev/whatsnew/3.8.html#os-path. I'm not
     sure that there are other ways to provoke this behavior on Unix other than the null byte,
@@ -135,6 +138,8 @@ def mkdir_p(path):
             raise
 
 
+# TODO: Make frozendict generic for type annotations
+# https://github.com/dagster-io/dagster/issues/3641
 class frozendict(dict):
     def __readonly__(self, *args, **kwargs):
         raise RuntimeError("Cannot modify ReadOnlyDict")
@@ -154,10 +159,10 @@ class frozendict(dict):
 
     __setitem__ = __readonly__
     __delitem__ = __readonly__
-    pop = __readonly__
+    pop = __readonly__  # type: ignore[assignment]
     popitem = __readonly__
     clear = __readonly__
-    update = __readonly__
+    update = __readonly__  # type: ignore[assignment]
     setdefault = __readonly__
     del __readonly__
 
@@ -166,7 +171,19 @@ class frozenlist(list):
     def __readonly__(self, *args, **kwargs):
         raise RuntimeError("Cannot modify ReadOnlyList")
 
-    __setitem__ = __readonly__
+    # https://docs.python.org/3/library/pickle.html#object.__reduce__
+    #
+    # Like frozendict, implement __reduce__ and __setstate__ to handle pickling.
+    # Otherwise, __setstate__ will be called to restore the frozenlist, causing
+    # a RuntimeError because frozenlist is not mutable.
+
+    def __reduce__(self):
+        return (frozenlist, (), list(self))
+
+    def __setstate__(self, state):
+        self.__init__(state)
+
+    __setitem__ = __readonly__  # type: ignore[assignment]
     __delitem__ = __readonly__
     append = __readonly__
     clear = __readonly__
@@ -175,7 +192,10 @@ class frozenlist(list):
     pop = __readonly__
     remove = __readonly__
     reverse = __readonly__
-    sort = __readonly__
+    sort = __readonly__  # type: ignore[assignment]
+
+    def __hash__(self):
+        return hash(tuple(self))
 
 
 def make_readonly_value(value):
@@ -242,7 +262,7 @@ def check_cli_execute_file_pipeline(path, pipeline_fn_name, env_file=None):
             raise cpe
 
 
-def safe_tempfile_path_unmanaged():
+def safe_tempfile_path_unmanaged() -> str:
     # This gets a valid temporary file path in the safest possible way, although there is still no
     # guarantee that another process will not create a file at this path. The NamedTemporaryFile is
     # deleted when the context manager exits and the file object is closed.
@@ -258,7 +278,7 @@ def safe_tempfile_path_unmanaged():
 
 
 @contextlib.contextmanager
-def safe_tempfile_path():
+def safe_tempfile_path() -> Iterator[str]:
     try:
         path = safe_tempfile_path_unmanaged()
         yield path
@@ -300,6 +320,10 @@ def touch_file(path):
 
 def _kill_on_event(termination_event):
     termination_event.wait()
+    send_interrupt()
+
+
+def send_interrupt():
     if IS_WINDOWS:
         # This will raise a KeyboardInterrupt in python land - meaning this wont be able to
         # interrupt things like sleep()
@@ -327,29 +351,18 @@ def start_termination_thread(termination_event):
     int_thread.start()
 
 
-# Wraps code that we don't want a SIGINT to interrupt (but throw a KeyboardInterrupt if a
-# SIGINT was received while it ran)
-@contextlib.contextmanager
-def delay_interrupts():
-    if not seven.is_main_thread():
-        yield
-    else:
-        original_signal_handler = signal.getsignal(signal.SIGINT)
+# Executes the next() function within an instance of the supplied context manager class
+# (leaving the context before yielding each result)
+def iterate_with_context(context, iterator):
+    while True:
+        # Allow interrupts during user code so that we can terminate slow/hanging steps
+        with context():
+            try:
+                next_output = next(iterator)
+            except StopIteration:
+                return
 
-        received_interrupt = {"received": False}
-
-        def _new_signal_handler(signo, _):
-            check.invariant(signo == signal.SIGINT)
-            received_interrupt["received"] = True
-
-        signal.signal(signal.SIGINT, _new_signal_handler)
-
-        try:
-            yield
-        finally:
-            signal.signal(signal.SIGINT, original_signal_handler)
-            if received_interrupt["received"]:
-                raise KeyboardInterrupt
+        yield next_output
 
 
 def datetime_as_float(dt):
@@ -375,8 +388,8 @@ class frozentags(frozendict):
         return frozentags(updated)
 
 
-class EventGenerationManager(object):
-    """ Utility class that wraps an event generator function, that also yields a single instance of
+class EventGenerationManager:
+    """Utility class that wraps an event generator function, that also yields a single instance of
     a typed object.  All events yielded before the typed object are yielded through the method
     `generate_setup_events` and all events yielded after the typed object are yielded through the
     method `generate_teardown_events`.
@@ -423,30 +436,36 @@ class EventGenerationManager(object):
     def generate_teardown_events(self):
         self.did_teardown = True
         if self.object:
-            for event in self.generator:
-                yield event
+            yield from self.generator
 
 
-def utc_datetime_from_timestamp(timestamp):
-    tz = None
+def utc_timezone():
     if sys.version_info.major >= 3 and sys.version_info.minor >= 2:
         from datetime import timezone
 
-        tz = timezone.utc
+        return timezone.utc
     else:
         import pytz
 
-        tz = pytz.utc
+        return pytz.utc
 
+
+def utc_datetime_from_timestamp(timestamp):
+    tz = utc_timezone()
     return datetime.datetime.fromtimestamp(timestamp, tz=tz)
 
 
+def utc_datetime_from_naive(dt):
+    tz = utc_timezone()
+    return dt.replace(tzinfo=tz)
+
+
 def is_enum_value(value):
     return False if value is None else issubclass(value.__class__, Enum)
 
 
 def git_repository_root():
-    return six.ensure_str(subprocess.check_output(["git", "rev-parse", "--show-toplevel"]).strip())
+    return subprocess.check_output(["git", "rev-parse", "--show-toplevel"]).decode("utf-8").strip()
 
 
 def segfault():
