@@ -1,5 +1,6 @@
 import os
 import shutil
+import tempfile
 import uuid
 from collections import defaultdict
 from contextlib import contextmanager
@@ -13,36 +14,33 @@ from dagster import (
     PipelineDefinition,
     RepositoryDefinition,
     SolidInvocation,
-    SystemStorageData,
     TypeCheck,
     check,
     execute_pipeline,
     lambda_solid,
-    seven,
 )
-from dagster.core.definitions.executable import InMemoryExecutablePipeline
 from dagster.core.definitions.logger import LoggerDefinition
+from dagster.core.definitions.pipeline_base import InMemoryPipeline
 from dagster.core.definitions.resource import ScopedResourcesBuilder
-from dagster.core.definitions.solid import ISolidDefinition
+from dagster.core.definitions.solid import NodeDefinition
 from dagster.core.execution.api import create_execution_plan, scoped_pipeline_context
 from dagster.core.execution.context_creation_pipeline import (
-    construct_pipeline_execution_context,
+    SystemPipelineExecutionContext,
+    construct_execution_context_data,
     create_context_creation_data,
     create_executor,
     create_log_manager,
 )
 from dagster.core.instance import DagsterInstance
-from dagster.core.scheduler import ScheduleStatus, Scheduler
+from dagster.core.scheduler import Scheduler
 from dagster.core.scheduler.scheduler import DagsterScheduleDoesNotExist, DagsterSchedulerError
 from dagster.core.snap import snapshot_from_execution_plan
 from dagster.core.storage.file_manager import LocalFileManager
-from dagster.core.storage.intermediates_manager import InMemoryIntermediatesManager
 from dagster.core.storage.pipeline_run import PipelineRun
 from dagster.core.types.dagster_type import resolve_dagster_type
 from dagster.core.utility_solids import define_stub_solid
 from dagster.core.utils import make_new_run_id
 from dagster.serdes import ConfigurableClass
-from dagster.utils.backcompat import canonicalize_run_config
 
 # pylint: disable=unused-import
 from ..temp_file import (
@@ -57,34 +55,35 @@ from ..typing_api import is_typing_type
 
 
 def create_test_pipeline_execution_context(logger_defs=None):
-    from dagster.core.storage.intermediates_manager import build_in_mem_intermediates_storage
+    from dagster.core.storage.intermediate_storage import build_in_mem_intermediates_storage
 
     loggers = check.opt_dict_param(
-        logger_defs, 'logger_defs', key_type=str, value_type=LoggerDefinition
+        logger_defs, "logger_defs", key_type=str, value_type=LoggerDefinition
     )
     mode_def = ModeDefinition(logger_defs=loggers)
     pipeline_def = PipelineDefinition(
-        name='test_legacy_context', solid_defs=[], mode_defs=[mode_def]
+        name="test_legacy_context", solid_defs=[], mode_defs=[mode_def]
     )
-    run_config = {'loggers': {key: {} for key in loggers}}
-    pipeline_run = PipelineRun(pipeline_name='test_legacy_context', run_config=run_config)
+    run_config = {"loggers": {key: {} for key in loggers}}
+    pipeline_run = PipelineRun(pipeline_name="test_legacy_context", run_config=run_config)
     instance = DagsterInstance.ephemeral()
     execution_plan = create_execution_plan(pipeline=pipeline_def, run_config=run_config)
     creation_data = create_context_creation_data(execution_plan, run_config, pipeline_run, instance)
     log_manager = create_log_manager(creation_data)
     scoped_resources_builder = ScopedResourcesBuilder()
     executor = create_executor(creation_data)
-    return construct_pipeline_execution_context(
-        context_creation_data=creation_data,
-        scoped_resources_builder=scoped_resources_builder,
-        system_storage_data=SystemStorageData(
-            intermediates_manager=InMemoryIntermediatesManager(),
-            file_manager=LocalFileManager.for_instance(instance, pipeline_run.run_id),
+
+    return SystemPipelineExecutionContext(
+        construct_execution_context_data(
+            context_creation_data=creation_data,
+            scoped_resources_builder=scoped_resources_builder,
+            intermediate_storage=build_in_mem_intermediates_storage(pipeline_run.run_id),
+            log_manager=log_manager,
+            retry_mode=executor.retries,
+            raise_on_error=True,
         ),
-        intermediate_storage=build_in_mem_intermediates_storage(pipeline_run.run_id),
-        log_manager=log_manager,
         executor=executor,
-        raise_on_error=True,
+        log_manager=log_manager,
     )
 
 
@@ -93,8 +92,8 @@ def _dep_key_of(solid):
 
 
 def build_pipeline_with_input_stubs(pipeline_def, inputs):
-    check.inst_param(pipeline_def, 'pipeline_def', PipelineDefinition)
-    check.dict_param(inputs, 'inputs', key_type=str, value_type=dict)
+    check.inst_param(pipeline_def, "pipeline_def", PipelineDefinition)
+    check.dict_param(inputs, "inputs", key_type=str, value_type=dict)
 
     deps = defaultdict(dict)
     for solid_name, dep_dict in pipeline_def.dependencies.items():
@@ -107,15 +106,15 @@ def build_pipeline_with_input_stubs(pipeline_def, inputs):
         if not pipeline_def.has_solid_named(solid_name):
             raise DagsterInvariantViolationError(
                 (
-                    'You are injecting an input value for solid {solid_name} '
-                    'into pipeline {pipeline_name} but that solid was not found'
+                    "You are injecting an input value for solid {solid_name} "
+                    "into pipeline {pipeline_name} but that solid was not found"
                 ).format(solid_name=solid_name, pipeline_name=pipeline_def.name)
             )
 
         solid = pipeline_def.solid_named(solid_name)
         for input_name, input_value in input_dict.items():
             stub_solid_def = define_stub_solid(
-                '__stub_{solid_name}_{input_name}'.format(
+                "__stub_{solid_name}_{input_name}".format(
                     solid_name=solid_name, input_name=input_name
                 ),
                 input_value,
@@ -124,7 +123,7 @@ def build_pipeline_with_input_stubs(pipeline_def, inputs):
             deps[_dep_key_of(solid)][input_name] = DependencyDefinition(stub_solid_def.name)
 
     return PipelineDefinition(
-        name=pipeline_def.name + '_stubbed',
+        name=pipeline_def.name + "_stubbed",
         solid_defs=pipeline_def.top_level_solid_defs + stub_solid_defs,
         mode_defs=pipeline_def.mode_definitions,
         dependencies=deps,
@@ -140,9 +139,8 @@ def execute_solids_within_pipeline(
     preset=None,
     tags=None,
     instance=None,
-    environment_dict=None,
 ):
-    '''Execute a set of solids within an existing pipeline.
+    """Execute a set of solids within an existing pipeline.
 
     Intended to support tests. Input values may be passed directly.
 
@@ -166,13 +164,10 @@ def execute_solids_within_pipeline(
     Returns:
         Dict[str, Union[CompositeSolidExecutionResult, SolidExecutionResult]]: The results of
         executing the solids, keyed by solid name.
-    '''
-    check.inst_param(pipeline_def, 'pipeline_def', PipelineDefinition)
-    check.set_param(solid_names, 'solid_names', of_type=str)
-    inputs = check.opt_dict_param(inputs, 'inputs', key_type=str, value_type=dict)
-
-    # backcompact
-    run_config = canonicalize_run_config(run_config, environment_dict)
+    """
+    check.inst_param(pipeline_def, "pipeline_def", PipelineDefinition)
+    check.set_param(solid_names, "solid_names", of_type=str)
+    inputs = check.opt_dict_param(inputs, "inputs", key_type=str, value_type=dict)
 
     sub_pipeline = pipeline_def.get_pipeline_subset_def(solid_names)
     stubbed_pipeline = build_pipeline_with_input_stubs(sub_pipeline, inputs)
@@ -197,9 +192,8 @@ def execute_solid_within_pipeline(
     preset=None,
     tags=None,
     instance=None,
-    environment_dict=None,
 ):
-    '''Execute a single solid within an existing pipeline.
+    """Execute a single solid within an existing pipeline.
 
     Intended to support tests. Input values may be passed directly.
 
@@ -223,9 +217,7 @@ def execute_solid_within_pipeline(
     Returns:
         Union[CompositeSolidExecutionResult, SolidExecutionResult]: The result of executing the
         solid.
-    '''
-    # backcompact
-    run_config = canonicalize_run_config(run_config, environment_dict)
+    """
 
     return execute_solids_within_pipeline(
         pipeline_def,
@@ -241,16 +233,16 @@ def execute_solid_within_pipeline(
 
 @contextmanager
 def yield_empty_pipeline_context(run_id=None, instance=None):
-    pipeline = InMemoryExecutablePipeline(PipelineDefinition([]))
+    pipeline = InMemoryPipeline(PipelineDefinition([], "empty"))
     pipeline_def = pipeline.get_definition()
     instance = check.opt_inst_param(
-        instance, 'instance', DagsterInstance, default=DagsterInstance.ephemeral()
+        instance, "instance", DagsterInstance, default=DagsterInstance.ephemeral()
     )
 
     execution_plan = create_execution_plan(pipeline)
 
     pipeline_run = instance.create_run(
-        pipeline_name='<empty>',
+        pipeline_name="<empty>",
         run_id=run_id,
         run_config=None,
         mode=None,
@@ -277,9 +269,8 @@ def execute_solid(
     tags=None,
     run_config=None,
     raise_on_error=True,
-    environment_dict=None,
 ):
-    '''Execute a single solid in an ephemeral pipeline.
+    """Execute a single solid in an ephemeral pipeline.
 
     Intended to support unit tests. Input values may be passed directly, and no pipeline need be
     specified -- an ephemeral pipeline will be constructed.
@@ -301,13 +292,10 @@ def execute_solid(
     Returns:
         Union[CompositeSolidExecutionResult, SolidExecutionResult]: The result of executing the
         solid.
-    '''
-    check.inst_param(solid_def, 'solid_def', ISolidDefinition)
-    check.opt_inst_param(mode_def, 'mode_def', ModeDefinition)
-    input_values = check.opt_dict_param(input_values, 'input_values', key_type=str)
-    # backcompact
-    run_config = canonicalize_run_config(run_config, environment_dict)
-
+    """
+    check.inst_param(solid_def, "solid_def", NodeDefinition)
+    check.opt_inst_param(mode_def, "mode_def", ModeDefinition)
+    input_values = check.opt_dict_param(input_values, "input_values", key_type=str)
     solid_defs = [solid_def]
 
     def create_value_solid(input_name, input_value):
@@ -325,7 +313,7 @@ def execute_solid(
 
     result = execute_pipeline(
         PipelineDefinition(
-            name='ephemeral_{}_solid_pipeline'.format(solid_def.name),
+            name="ephemeral_{}_solid_pipeline".format(solid_def.name),
             solid_defs=solid_defs,
             dependencies=dependencies,
             mode_defs=[mode_def] if mode_def else None,
@@ -339,7 +327,7 @@ def execute_solid(
 
 
 def check_dagster_type(dagster_type, value):
-    '''Test a custom Dagster type.
+    """Test a custom Dagster type.
 
     Args:
         dagster_type (Any): The Dagster type to test. Should be one of the
@@ -357,13 +345,13 @@ def check_dagster_type(dagster_type, value):
         .. code-block:: python
 
             assert check_dagster_type(Dict[Any, Any], {'foo': 'bar'}).success
-    '''
+    """
 
     if is_typing_type(dagster_type):
         raise DagsterInvariantViolationError(
             (
-                'Must pass in a type from dagster module. You passed {dagster_type} '
-                'which is part of python\'s typing module.'
+                "Must pass in a type from dagster module. You passed {dagster_type} "
+                "which is part of python's typing module."
             ).format(dagster_type=dagster_type)
         )
 
@@ -377,34 +365,30 @@ def check_dagster_type(dagster_type, value):
 
         if not isinstance(type_check, TypeCheck):
             raise DagsterInvariantViolationError(
-                'Type checks can only return TypeCheck. Type {type_name} returned {value}.'.format(
-                    type_name=dagster_type.name, value=repr(type_check)
+                "Type checks can only return TypeCheck. Type {type_name} returned {value}.".format(
+                    type_name=dagster_type.display_name, value=repr(type_check)
                 )
             )
         return type_check
 
 
 @contextmanager
-def restore_directory(src):
-    with seven.TemporaryDirectory() as temp_dir:
+def copy_directory(src):
+    with tempfile.TemporaryDirectory() as temp_dir:
         dst = os.path.join(temp_dir, os.path.basename(src))
         shutil.copytree(src, dst)
-        try:
-            yield
-        finally:
-            shutil.rmtree(src)
-            shutil.copytree(dst, src)
+        yield dst
 
 
 class FilesystemTestScheduler(Scheduler, ConfigurableClass):
-    '''This class is used in dagster core and dagster_graphql to test the scheduler's interactions
+    """This class is used in dagster core and dagster_graphql to test the scheduler's interactions
     with schedule storage, which are implemented in the methods defined on the base Scheduler class.
     Therefore, the following methods used to actually schedule jobs (e.g. create and remove cron jobs
-    on a cron tab) are left unimimplemented.
-    '''
+    on a cron tab) are left unimplemented.
+    """
 
     def __init__(self, artifacts_dir, inst_data=None):
-        check.str_param(artifacts_dir, 'artifacts_dir')
+        check.str_param(artifacts_dir, "artifacts_dir")
         self._artifacts_dir = artifacts_dir
         self._inst_data = inst_data
 
@@ -414,11 +398,11 @@ class FilesystemTestScheduler(Scheduler, ConfigurableClass):
 
     @classmethod
     def config_type(cls):
-        return {'base_dir': str}
+        return {"base_dir": str}
 
     @staticmethod
     def from_config_value(inst_data, config_value):
-        return FilesystemTestScheduler(artifacts_dir=config_value['base_dir'], inst_data=inst_data)
+        return FilesystemTestScheduler(artifacts_dir=config_value["base_dir"], inst_data=inst_data)
 
     def debug_info(self):
         return ""
@@ -429,12 +413,12 @@ class FilesystemTestScheduler(Scheduler, ConfigurableClass):
     def stop_schedule(self, instance, schedule_origin_id):
         pass
 
-    def running_schedule_count(self, schedule_origin_id):
+    def running_schedule_count(self, instance, schedule_origin_id):
         return 0
 
     def get_logs_path(self, _instance, schedule_origin_id):
-        check.str_param(schedule_origin_id, 'schedule_origin_id')
-        return os.path.join(self._artifacts_dir, 'logs', schedule_origin_id, 'scheduler.log')
+        check.str_param(schedule_origin_id, "schedule_origin_id")
+        return os.path.join(self._artifacts_dir, "logs", schedule_origin_id, "scheduler.log")
 
     def wipe(self, instance):
         pass
