@@ -1,36 +1,34 @@
-from __future__ import print_function
-
 import json
 import os
 import string
+import sys
+import tempfile
 from contextlib import contextmanager
 
 import mock
 import pytest
 from click.testing import CliRunner
-
 from dagster import (
+    Partition,
     PartitionSetDefinition,
     PresetDefinition,
     ScheduleDefinition,
-    Shape,
-    check,
+    execute_pipeline,
     lambda_solid,
     pipeline,
     repository,
-    seven,
     solid,
 )
-from dagster.cli.run import run_list_command, run_wipe_command
-from dagster.core.host_representation import ExternalPipeline
-from dagster.core.instance import DagsterInstance
-from dagster.core.launcher import RunLauncher
-from dagster.core.storage.pipeline_run import PipelineRun
-from dagster.core.test_utils import instance_for_test_tempdir
+from dagster.cli import ENV_PREFIX, cli
+from dagster.cli.pipeline import pipeline_execute_command
+from dagster.cli.run import run_delete_command, run_list_command, run_wipe_command
+from dagster.core.definitions.decorators.sensor import sensor
+from dagster.core.definitions.sensor import RunRequest
+from dagster.core.test_utils import instance_for_test, instance_for_test_tempdir
 from dagster.core.types.loadable_target_origin import LoadableTargetOrigin
 from dagster.grpc.server import GrpcServerProcess
-from dagster.serdes import ConfigurableClass
 from dagster.utils import file_relative_path, merge_dicts
+from dagster.version import __version__
 
 
 def no_print(_):
@@ -48,7 +46,10 @@ def do_input(x):
 
 
 @pipeline(
-    name="foo", preset_defs=[PresetDefinition(name="test", tags={"foo": "bar"}),],
+    name="foo",
+    preset_defs=[
+        PresetDefinition(name="test", tags={"foo": "bar"}),
+    ],
 )
 def foo_pipeline():
     do_input(do_something())
@@ -83,10 +84,15 @@ def define_bar_schedules():
     )
     return {
         "foo_schedule": ScheduleDefinition(
-            "foo_schedule", cron_schedule="* * * * *", pipeline_name="test_pipeline", run_config={},
+            "foo_schedule",
+            cron_schedule="* * * * *",
+            pipeline_name="test_pipeline",
+            run_config={},
         ),
         "partitioned_schedule": partition_set.create_schedule_definition(
-            schedule_name="partitioned_schedule", cron_schedule="* * * * *"
+            schedule_name="partitioned_schedule",
+            cron_schedule="* * * * *",
+            partition_selector=lambda _context, _def: Partition("7"),
         ),
     }
 
@@ -108,14 +114,29 @@ def define_bar_partitions():
             },
         ),
         "error_name_partitions": PartitionSetDefinition(
-            name="error_name_partitions", pipeline_name="baz", partition_fn=error_name,
+            name="error_name_partitions",
+            pipeline_name="baz",
+            partition_fn=error_name,
         ),
         "error_config_partitions": PartitionSetDefinition(
-            name="error_config_partitions", pipeline_name="baz", partition_fn=error_config,
+            name="error_config_partitions",
+            pipeline_name="baz",
+            partition_fn=error_config,
         ),
     }
 
 
+def define_bar_sensors():
+    @sensor(pipeline_name="baz")
+    def foo_sensor(context):
+        run_config = {"foo": "FOO"}
+        if context.last_completion_time:
+            run_config["since"] = context.last_completion_time
+        return RunRequest(run_key=None, run_config=run_config)
+
+    return {"foo_sensor": foo_sensor}
+
+
 @repository
 def bar():
     return {
@@ -126,6 +147,7 @@ def bar():
         },
         "schedules": define_bar_schedules(),
         "partition_sets": define_bar_partitions(),
+        "sensors": define_bar_sensors(),
     }
 
 
@@ -149,46 +171,12 @@ def stderr_pipeline():
     fail()
 
 
-class InMemoryRunLauncher(RunLauncher, ConfigurableClass):
-    def __init__(self, inst_data=None):
-        self._inst_data = inst_data
-        self._queue = []
-
-    def launch_run(self, instance, run, external_pipeline):
-        check.inst_param(instance, "instance", DagsterInstance)
-        check.inst_param(run, "run", PipelineRun)
-        check.inst_param(external_pipeline, "external_pipeline", ExternalPipeline)
-        self._queue.append(run)
-        return run
-
-    def queue(self):
-        return self._queue
-
-    @classmethod
-    def config_type(cls):
-        return Shape({})
-
-    @classmethod
-    def from_config_value(cls, inst_data, config_value):
-        return cls(inst_data=inst_data,)
-
-    @property
-    def inst_data(self):
-        return self._inst_data
-
-    def can_terminate(self, run_id):
-        return False
-
-    def terminate(self, run_id):
-        check.not_implemented("Termintation not supported")
-
-
 @contextmanager
-def default_instance_tempdir(temp_dir, overrides=None):
+def _default_cli_test_instance_tempdir(temp_dir, overrides=None):
     default_overrides = {
         "run_launcher": {
-            "module": "dagster_tests.cli_tests.command_tests.test_cli_commands",
-            "class": "InMemoryRunLauncher",
+            "module": "dagster.core.test_utils",
+            "class": "MockedRunLauncher",
         }
     }
     with instance_for_test_tempdir(
@@ -200,35 +188,29 @@ def default_instance_tempdir(temp_dir, overrides=None):
 
 
 @contextmanager
-def default_instance(overrides=None):
-    with seven.TemporaryDirectory() as temp_dir:
-        with default_instance_tempdir(temp_dir, overrides) as instance:
+def default_cli_test_instance(overrides=None):
+    with tempfile.TemporaryDirectory() as temp_dir:
+        with _default_cli_test_instance_tempdir(temp_dir, overrides) as instance:
             yield instance
 
 
-def managed_grpc_instance():
-    return default_instance(overrides={"opt_in": {"local_servers": True}})
-
-
 @contextmanager
 def args_with_instance(gen_instance, *args):
     with gen_instance as instance:
         yield args + (instance,)
 
 
-def args_with_default_instance(*args):
-    return args_with_instance(default_instance(), *args)
-
-
-def args_with_managed_grpc_instance(*args):
-    return args_with_instance(managed_grpc_instance(), *args)
+def args_with_default_cli_test_instance(*args):
+    return args_with_instance(default_cli_test_instance(), *args)
 
 
 @contextmanager
 def grpc_server_bar_kwargs(pipeline_name=None):
     server_process = GrpcServerProcess(
         loadable_target_origin=LoadableTargetOrigin(
-            python_file=file_relative_path(__file__, "test_cli_commands.py"), attribute="bar"
+            executable_path=sys.executable,
+            python_file=file_relative_path(__file__, "test_cli_commands.py"),
+            attribute="bar",
         ),
     )
     with server_process.create_ephemeral_client() as client:
@@ -261,7 +243,9 @@ def python_bar_cli_args(pipeline_name=None):
 def grpc_server_bar_cli_args(pipeline_name=None):
     server_process = GrpcServerProcess(
         loadable_target_origin=LoadableTargetOrigin(
-            python_file=file_relative_path(__file__, "test_cli_commands.py"), attribute="bar"
+            executable_path=sys.executable,
+            python_file=file_relative_path(__file__, "test_cli_commands.py"),
+            attribute="bar",
         ),
     )
     with server_process.create_ephemeral_client() as client:
@@ -282,33 +266,30 @@ def grpc_server_bar_cli_args(pipeline_name=None):
 
 @contextmanager
 def grpc_server_bar_pipeline_args():
-    with default_instance() as instance:
+    with default_cli_test_instance() as instance:
         with grpc_server_bar_kwargs(pipeline_name="foo") as kwargs:
-            yield kwargs, False, instance
+            yield kwargs, instance
 
 
 # This iterates over a list of contextmanagers that can be used to contruct
-# (cli_args, uses_legacy_repository_yaml_format, instance tuples)
+# (cli_args, instance tuples)
 def launch_command_contexts():
     for pipeline_target_args in valid_external_pipeline_target_args():
-        yield args_with_default_instance(*pipeline_target_args)
-        yield pytest.param(
-            args_with_managed_grpc_instance(*pipeline_target_args), marks=pytest.mark.managed_grpc
-        )
-    yield pytest.param(grpc_server_bar_pipeline_args(), marks=pytest.mark.deployed_grpc)
+        yield args_with_default_cli_test_instance(pipeline_target_args)
+    yield pytest.param(grpc_server_bar_pipeline_args())
 
 
 def pipeline_python_origin_contexts():
     return [
-        args_with_default_instance(pipeline_target_args)
+        args_with_default_cli_test_instance(pipeline_target_args)
         for pipeline_target_args in valid_pipeline_python_origin_target_args()
     ]
 
 
 @contextmanager
 def scheduler_instance(overrides=None):
-    with seven.TemporaryDirectory() as temp_dir:
-        with default_instance_tempdir(
+    with tempfile.TemporaryDirectory() as temp_dir:
+        with _default_cli_test_instance_tempdir(
             temp_dir,
             overrides=merge_dicts(
                 {
@@ -324,13 +305,9 @@ def scheduler_instance(overrides=None):
             yield instance
 
 
-def managed_grpc_scheduler_instance():
-    return scheduler_instance(overrides={"opt_in": {"local_servers": True}})
-
-
 @contextmanager
-def grpc_server_scheduler_cli_args():
-    with scheduler_instance() as instance:
+def grpc_server_scheduler_cli_args(overrides=None):
+    with scheduler_instance(overrides) as instance:
         with grpc_server_bar_cli_args() as args:
             yield args, instance
 
@@ -342,39 +319,48 @@ def schedule_command_contexts():
         args_with_instance(
             scheduler_instance(), ["-w", file_relative_path(__file__, "workspace.yaml")]
         ),
-        pytest.param(
-            args_with_instance(
-                managed_grpc_scheduler_instance(),
-                ["-w", file_relative_path(__file__, "workspace.yaml")],
-            ),
-            marks=pytest.mark.managed_grpc,
+        grpc_server_scheduler_cli_args(),
+    ]
+
+
+def sensor_command_contexts():
+    return [
+        args_with_instance(
+            scheduler_instance(),
+            ["-w", file_relative_path(__file__, "workspace.yaml")],
         ),
-        pytest.param(grpc_server_scheduler_cli_args(), marks=pytest.mark.deployed_grpc),
+        grpc_server_scheduler_cli_args(),
     ]
 
 
 # This iterates over a list of contextmanagers that can be used to contruct
-# (cli_args, uses_legacy_repository_yaml_format, instance) tuples for backfill calls
+# (cli_args, instance) tuples for backfill calls
 def backfill_command_contexts():
     repo_args = {
         "noprompt": True,
         "workspace": (file_relative_path(__file__, "repository_file.yaml"),),
     }
     return [
-        args_with_instance(default_instance(), repo_args, True),
-        pytest.param(
-            args_with_instance(managed_grpc_instance(), repo_args, True),
-            marks=pytest.mark.managed_grpc,
-        ),
-        pytest.param(grpc_server_backfill_args(), marks=pytest.mark.deployed_grpc),
+        args_with_instance(default_cli_test_instance(), repo_args),
+        grpc_server_backfill_args(),
     ]
 
 
 @contextmanager
 def grpc_server_backfill_args():
-    with default_instance() as instance:
+    with default_cli_test_instance() as instance:
         with grpc_server_bar_kwargs() as args:
-            yield merge_dicts(args, {"noprompt": True}), False, instance
+            yield merge_dicts(args, {"noprompt": True}), instance
+
+
+def non_existant_python_origin_target_args():
+    return {
+        "workspace": None,
+        "pipeline": "foo",
+        "python_file": file_relative_path(__file__, "made_up_file.py"),
+        "module_name": None,
+        "attribute": "bar",
+    }
 
 
 def valid_pipeline_python_origin_target_args():
@@ -401,6 +387,13 @@ def valid_pipeline_python_origin_target_args():
             "module_name": "dagster_tests.cli_tests.command_tests.test_cli_commands",
             "attribute": "bar",
         },
+        {
+            "workspace": None,
+            "pipeline": "foo",
+            "python_file": None,
+            "package_name": "dagster_tests.cli_tests.command_tests.test_cli_commands",
+            "attribute": "bar",
+        },
         {
             "workspace": None,
             "pipeline": None,
@@ -408,6 +401,13 @@ def valid_pipeline_python_origin_target_args():
             "module_name": "dagster_tests.cli_tests.command_tests.test_cli_commands",
             "attribute": "foo_pipeline",
         },
+        {
+            "workspace": None,
+            "pipeline": None,
+            "python_file": None,
+            "package_name": "dagster_tests.cli_tests.command_tests.test_cli_commands",
+            "attribute": "foo_pipeline",
+        },
         {
             "workspace": None,
             "pipeline": None,
@@ -433,30 +433,23 @@ def valid_pipeline_python_origin_target_args():
     ]
 
 
-# [(cli_args, uses_legacy_repository_yaml_format)]
 def valid_external_pipeline_target_args():
     return [
-        (
-            {
-                "workspace": (file_relative_path(__file__, "repository_file.yaml"),),
-                "pipeline": "foo",
-                "python_file": None,
-                "module_name": None,
-                "attribute": None,
-            },
-            True,
-        ),
-        (
-            {
-                "workspace": (file_relative_path(__file__, "repository_module.yaml"),),
-                "pipeline": "foo",
-                "python_file": None,
-                "module_name": None,
-                "attribute": None,
-            },
-            True,
-        ),
-    ] + [(args, False) for args in valid_pipeline_python_origin_target_args()]
+        {
+            "workspace": (file_relative_path(__file__, "repository_file.yaml"),),
+            "pipeline": "foo",
+            "python_file": None,
+            "module_name": None,
+            "attribute": None,
+        },
+        {
+            "workspace": (file_relative_path(__file__, "repository_module.yaml"),),
+            "pipeline": "foo",
+            "python_file": None,
+            "module_name": None,
+            "attribute": None,
+        },
+    ] + [args for args in valid_pipeline_python_origin_target_args()]
 
 
 def valid_pipeline_python_origin_target_cli_args():
@@ -481,7 +474,12 @@ def valid_pipeline_python_origin_target_cli_args():
             "foo",
         ],
         ["-m", "dagster_tests.cli_tests.command_tests.test_cli_commands", "-a", "foo_pipeline"],
-        ["-f", file_relative_path(__file__, "test_cli_commands.py"), "-a", "define_foo_pipeline",],
+        [
+            "-f",
+            file_relative_path(__file__, "test_cli_commands.py"),
+            "-a",
+            "define_foo_pipeline",
+        ],
         [
             "-f",
             file_relative_path(__file__, "test_cli_commands.py"),
@@ -493,73 +491,169 @@ def valid_pipeline_python_origin_target_cli_args():
     ]
 
 
-# [(cli_args, uses_legacy_repository_yaml_format)]
 def valid_external_pipeline_target_cli_args_no_preset():
     return [
-        (["-w", file_relative_path(__file__, "repository_file.yaml"), "-p", "foo"], True),
-        (["-w", file_relative_path(__file__, "repository_module.yaml"), "-p", "foo"], True),
-        (["-w", file_relative_path(__file__, "workspace.yaml"), "-p", "foo"], False),
-        (
-            [
-                "-w",
-                file_relative_path(__file__, "override.yaml"),
-                "-w",
-                file_relative_path(__file__, "workspace.yaml"),
-                "-p",
-                "foo",
-            ],
-            False,
-        ),
-    ] + [(args, False) for args in valid_pipeline_python_origin_target_cli_args()]
+        ["-w", file_relative_path(__file__, "repository_file.yaml"), "-p", "foo"],
+        ["-w", file_relative_path(__file__, "repository_module.yaml"), "-p", "foo"],
+        ["-w", file_relative_path(__file__, "workspace.yaml"), "-p", "foo"],
+        [
+            "-w",
+            file_relative_path(__file__, "override.yaml"),
+            "-w",
+            file_relative_path(__file__, "workspace.yaml"),
+            "-p",
+            "foo",
+        ],
+    ] + [args for args in valid_pipeline_python_origin_target_cli_args()]
 
 
 def valid_external_pipeline_target_cli_args_with_preset():
     run_config = {"storage": {"filesystem": {"config": {"base_dir": "/tmp"}}}}
     return valid_external_pipeline_target_cli_args_no_preset() + [
-        (
-            [
-                "-f",
-                file_relative_path(__file__, "test_cli_commands.py"),
-                "-d",
-                os.path.dirname(__file__),
-                "-a",
-                "define_foo_pipeline",
-                "--preset",
-                "test",
-            ],
-            False,
-        ),
-        (
-            [
-                "-f",
-                file_relative_path(__file__, "test_cli_commands.py"),
-                "-d",
-                os.path.dirname(__file__),
-                "-a",
-                "define_foo_pipeline",
-                "--config-json",
-                json.dumps(run_config),
-            ],
-            False,
-        ),
+        [
+            "-f",
+            file_relative_path(__file__, "test_cli_commands.py"),
+            "-d",
+            os.path.dirname(__file__),
+            "-a",
+            "define_foo_pipeline",
+            "--preset",
+            "test",
+        ],
+        [
+            "-f",
+            file_relative_path(__file__, "test_cli_commands.py"),
+            "-d",
+            os.path.dirname(__file__),
+            "-a",
+            "define_foo_pipeline",
+            "--config-json",
+            json.dumps(run_config),
+        ],
     ]
 
 
 def test_run_list():
-    runner = CliRunner()
-    result = runner.invoke(run_list_command)
-    assert result.exit_code == 0
+    with instance_for_test():
+        runner = CliRunner()
+        result = runner.invoke(run_list_command)
+        assert result.exit_code == 0
 
 
 def test_run_wipe_correct_delete_message():
-    runner = CliRunner()
-    result = runner.invoke(run_wipe_command, input="DELETE\n")
-    assert "Deleted all run history and event logs" in result.output
-    assert result.exit_code == 0
+    with instance_for_test():
+        runner = CliRunner()
+        result = runner.invoke(run_wipe_command, input="DELETE\n")
+        assert "Deleted all run history and event logs" in result.output
+        assert result.exit_code == 0
 
 
 def test_run_wipe_incorrect_delete_message():
-    runner = CliRunner()
-    result = runner.invoke(run_wipe_command, input="WRONG\n")
-    assert "Exiting without deleting all run history and event logs" in result.output
+    with instance_for_test():
+        runner = CliRunner()
+        result = runner.invoke(run_wipe_command, input="WRONG\n")
+        assert "Exiting without deleting all run history and event logs" in result.output
+        assert result.exit_code == 0
+
+
+def test_run_delete_bad_id():
+    with instance_for_test():
+        runner = CliRunner()
+        result = runner.invoke(run_delete_command, args=["1234"], input="DELETE\n")
+        assert "No run found with id 1234" in result.output
+        assert result.exit_code == 0
+
+
+def test_run_delete_correct_delete_message():
+    with instance_for_test() as instance:
+        pipeline_result = execute_pipeline(foo_pipeline, instance=instance)
+        runner = CliRunner()
+        result = runner.invoke(run_delete_command, args=[pipeline_result.run_id], input="DELETE\n")
+        assert "Deleted run" in result.output
+        assert result.exit_code == 0
+
+
+def test_run_delete_incorrect_delete_message():
+    with instance_for_test() as instance:
+        pipeline_result = execute_pipeline(foo_pipeline, instance=instance)
+        runner = CliRunner()
+        result = runner.invoke(run_delete_command, args=[pipeline_result.run_id], input="Wrong\n")
+        assert "Exiting without deleting" in result.output
+        assert result.exit_code == 0
+
+
+def test_run_list_limit():
+    with instance_for_test():
+        runner = CliRunner()
+
+        runner_pipeline_execute(
+            runner,
+            [
+                "-f",
+                file_relative_path(__file__, "../../general_tests/test_repository.py"),
+                "-a",
+                "dagster_test_repository",
+                "--preset",
+                "add",
+                "-p",
+                "multi_mode_with_resources",  # pipeline name
+            ],
+        )
+
+        runner_pipeline_execute(
+            runner,
+            [
+                "-f",
+                file_relative_path(__file__, "../../general_tests/test_repository.py"),
+                "-a",
+                "dagster_test_repository",
+                "--preset",
+                "add",
+                "-p",
+                "multi_mode_with_resources",  # pipeline name
+            ],
+        )
+
+        # Should only shows one run because of the limit argument
+        result = runner.invoke(run_list_command, args="--limit 1")
+        assert result.exit_code == 0
+        assert result.output.count("Run: ") == 1
+        assert result.output.count("Pipeline: multi_mode_with_resources") == 1
+
+        # Shows two runs because of the limit argument is now 2
+        two_results = runner.invoke(run_list_command, args="--limit 2")
+        assert two_results.exit_code == 0
+        assert two_results.output.count("Run: ") == 2
+        assert two_results.output.count("Pipeline: multi_mode_with_resources") == 2
+
+        # Should only shows two runs although the limit argument is 3 because there are only 2 runs
+        shows_two_results = runner.invoke(run_list_command, args="--limit 3")
+        assert shows_two_results.exit_code == 0
+        assert shows_two_results.output.count("Run: ") == 2
+        assert shows_two_results.output.count("Pipeline: multi_mode_with_resources") == 2
+
+
+def runner_pipeline_execute(runner, cli_args):
+    result = runner.invoke(pipeline_execute_command, cli_args)
+    if result.exit_code != 0:
+        # CliRunner captures stdout so printing it out here
+        raise Exception(
+            (
+                "dagster pipeline execute commands with cli_args {cli_args} "
+                'returned exit_code {exit_code} with stdout:\n"{stdout}" and '
+                '\nresult as string: "{result}"'
+            ).format(
+                cli_args=cli_args, exit_code=result.exit_code, stdout=result.stdout, result=result
+            )
+        )
+    return result
+
+
+def test_use_env_vars_for_cli_option():
+    env_key = "{}_VERSION".format(ENV_PREFIX)
+    runner = CliRunner(env={env_key: "1"})
+    # use `debug` subcommand to trigger the cli group option flag `--version`
+    # see issue: https://github.com/pallets/click/issues/1694
+    result = runner.invoke(cli, ["debug"], auto_envvar_prefix=ENV_PREFIX)
+    assert __version__ in result.output
     assert result.exit_code == 0
