@@ -1,13 +1,27 @@
 import pytest
-
-from dagster import DagsterInstance, check, pipeline, solid
+from dagster import (
+    DagsterInstance,
+    Int,
+    Output,
+    OutputDefinition,
+    check,
+    composite_solid,
+    execute_pipeline,
+    lambda_solid,
+    pipeline,
+    solid,
+)
 from dagster.core.errors import (
-    DagsterIncompleteExecutionPlanError,
     DagsterInvalidConfigError,
+    DagsterInvariantViolationError,
     DagsterUnknownStepStateError,
 )
 from dagster.core.execution.api import create_execution_plan, execute_plan
-from dagster.core.execution.retries import Retries, RetryMode
+from dagster.core.execution.plan.outputs import StepOutputHandle
+from dagster.core.execution.plan.plan import should_skip_step
+from dagster.core.execution.retries import RetryMode
+from dagster.core.storage.pipeline_run import PipelineRun
+from dagster.core.utils import make_new_run_id
 
 from ..engine_tests.test_multiprocessing import define_diamond_pipeline
 
@@ -15,59 +29,63 @@ from ..engine_tests.test_multiprocessing import define_diamond_pipeline
 def test_topological_sort():
     plan = create_execution_plan(define_diamond_pipeline())
 
-    levels = plan.topological_step_levels()
+    levels = plan.get_steps_to_execute_by_level()
 
     assert len(levels) == 3
 
-    assert [step.key for step in levels[0]] == ["return_two.compute"]
-    assert [step.key for step in levels[1]] == ["add_three.compute", "mult_three.compute"]
-    assert [step.key for step in levels[2]] == ["adder.compute"]
+    assert [step.key for step in levels[0]] == ["return_two"]
+    assert [step.key for step in levels[1]] == ["add_three", "mult_three"]
+    assert [step.key for step in levels[2]] == ["adder"]
 
 
 def test_create_execution_plan_with_bad_inputs():
     with pytest.raises(DagsterInvalidConfigError):
         create_execution_plan(
-            define_diamond_pipeline(), run_config={"solids": {"add_three": {"inputs": {"num": 3}}}},
+            define_diamond_pipeline(),
+            run_config={"solids": {"add_three": {"inputs": {"num": 3}}}},
         )
 
 
 def test_active_execution_plan():
     plan = create_execution_plan(define_diamond_pipeline())
 
-    with plan.start(retries=Retries(RetryMode.DISABLED)) as active_execution:
+    with plan.start(retry_mode=(RetryMode.DISABLED)) as active_execution:
 
         steps = active_execution.get_steps_to_execute()
         assert len(steps) == 1
         step_1 = steps[0]
-        assert step_1.key == "return_two.compute"
+        assert step_1.key == "return_two"
 
         steps = active_execution.get_steps_to_execute()
         assert len(steps) == 0  # cant progress
 
         active_execution.mark_success(step_1.key)
+        active_execution.mark_step_produced_output(StepOutputHandle(step_1.key, "result"))
 
         steps = active_execution.get_steps_to_execute()
         assert len(steps) == 2
         step_2 = steps[0]
         step_3 = steps[1]
-        assert step_2.key == "add_three.compute"
-        assert step_3.key == "mult_three.compute"
+        assert step_2.key == "add_three"
+        assert step_3.key == "mult_three"
 
         steps = active_execution.get_steps_to_execute()
         assert len(steps) == 0  # cant progress
 
         active_execution.mark_success(step_2.key)
+        active_execution.mark_step_produced_output(StepOutputHandle(step_2.key, "result"))
 
         steps = active_execution.get_steps_to_execute()
         assert len(steps) == 0  # cant progress
 
         active_execution.mark_success(step_3.key)
+        active_execution.mark_step_produced_output(StepOutputHandle(step_3.key, "result"))
 
         steps = active_execution.get_steps_to_execute()
         assert len(steps) == 1
         step_4 = steps[0]
 
-        assert step_4.key == "adder.compute"
+        assert step_4.key == "adder"
 
         steps = active_execution.get_steps_to_execute()
         assert len(steps) == 0  # cant progress
@@ -83,35 +101,38 @@ def test_failing_execution_plan():
     pipeline_def = define_diamond_pipeline()
     plan = create_execution_plan(pipeline_def)
 
-    with plan.start(retries=Retries(RetryMode.DISABLED)) as active_execution:
+    with plan.start(retry_mode=(RetryMode.DISABLED)) as active_execution:
 
         steps = active_execution.get_steps_to_execute()
         assert len(steps) == 1
         step_1 = steps[0]
-        assert step_1.key == "return_two.compute"
+        assert step_1.key == "return_two"
 
         steps = active_execution.get_steps_to_execute()
         assert len(steps) == 0  # cant progress
 
         active_execution.mark_success(step_1.key)
+        active_execution.mark_step_produced_output(StepOutputHandle(step_1.key, "result"))
 
         steps = active_execution.get_steps_to_execute()
         assert len(steps) == 2
         step_2 = steps[0]
         step_3 = steps[1]
-        assert step_2.key == "add_three.compute"
-        assert step_3.key == "mult_three.compute"
+        assert step_2.key == "add_three"
+        assert step_3.key == "mult_three"
 
         steps = active_execution.get_steps_to_execute()
         assert len(steps) == 0  # cant progress
 
         active_execution.mark_success(step_2.key)
+        active_execution.mark_step_produced_output(StepOutputHandle(step_2.key, "result"))
 
         steps = active_execution.get_steps_to_execute()
         assert len(steps) == 0  # cant progress
 
         # uh oh failure
         active_execution.mark_failed(step_3.key)
+        active_execution.mark_step_produced_output(StepOutputHandle(step_3.key, "result"))
 
         # cant progres to 4th step
         steps = active_execution.get_steps_to_execute()
@@ -119,12 +140,12 @@ def test_failing_execution_plan():
 
         assert not active_execution.is_complete
 
-        steps = active_execution.get_steps_to_skip()
+        steps = active_execution.get_steps_to_abandon()
         assert len(steps) == 1
         step_4 = steps[0]
 
-        assert step_4.key == "adder.compute"
-        active_execution.mark_skipped(step_4.key)
+        assert step_4.key == "adder"
+        active_execution.mark_abandoned(step_4.key)
 
         assert active_execution.is_complete
 
@@ -133,12 +154,12 @@ def test_retries_active_execution():
     pipeline_def = define_diamond_pipeline()
     plan = create_execution_plan(pipeline_def)
 
-    with plan.start(retries=Retries(RetryMode.ENABLED)) as active_execution:
+    with plan.start(retry_mode=(RetryMode.ENABLED)) as active_execution:
 
         steps = active_execution.get_steps_to_execute()
         assert len(steps) == 1
         step_1 = steps[0]
-        assert step_1.key == "return_two.compute"
+        assert step_1.key == "return_two"
 
         steps = active_execution.get_steps_to_execute()
         assert len(steps) == 0  # cant progress
@@ -147,27 +168,29 @@ def test_retries_active_execution():
 
         steps = active_execution.get_steps_to_execute()
         assert len(steps) == 1
-        assert steps[0].key == "return_two.compute"
+        assert steps[0].key == "return_two"
 
         active_execution.mark_up_for_retry(step_1.key)
 
         steps = active_execution.get_steps_to_execute()
         assert len(steps) == 1
-        assert steps[0].key == "return_two.compute"
+        assert steps[0].key == "return_two"
 
         active_execution.mark_success(step_1.key)
+        active_execution.mark_step_produced_output(StepOutputHandle(step_1.key, "result"))
 
         steps = active_execution.get_steps_to_execute()
         assert len(steps) == 2
         step_2 = steps[0]
         step_3 = steps[1]
-        assert step_2.key == "add_three.compute"
-        assert step_3.key == "mult_three.compute"
+        assert step_2.key == "add_three"
+        assert step_3.key == "mult_three"
 
         steps = active_execution.get_steps_to_execute()
         assert len(steps) == 0  # cant progress
 
         active_execution.mark_success(step_2.key)
+        active_execution.mark_step_produced_output(StepOutputHandle(step_2.key, "result"))
 
         steps = active_execution.get_steps_to_execute()
         assert len(steps) == 0  # cant progress
@@ -181,12 +204,12 @@ def test_retries_active_execution():
 
         assert not active_execution.is_complete
 
-        steps = active_execution.get_steps_to_skip()
+        steps = active_execution.get_steps_to_abandon()
         assert len(steps) == 1
         step_4 = steps[0]
 
-        assert step_4.key == "adder.compute"
-        active_execution.mark_skipped(step_4.key)
+        assert step_4.key == "adder"
+        active_execution.mark_abandoned(step_4.key)
 
         assert active_execution.is_complete
 
@@ -196,12 +219,12 @@ def test_retries_disabled_active_execution():
     plan = create_execution_plan(pipeline_def)
 
     with pytest.raises(check.CheckError):
-        with plan.start(retries=Retries(RetryMode.DISABLED)) as active_execution:
+        with plan.start(retry_mode=(RetryMode.DISABLED)) as active_execution:
 
             steps = active_execution.get_steps_to_execute()
             assert len(steps) == 1
             step_1 = steps[0]
-            assert step_1.key == "return_two.compute"
+            assert step_1.key == "return_two"
 
             steps = active_execution.get_steps_to_execute()
             assert len(steps) == 0  # cant progress
@@ -214,12 +237,12 @@ def test_retries_deferred_active_execution():
     pipeline_def = define_diamond_pipeline()
     plan = create_execution_plan(pipeline_def)
 
-    with plan.start(retries=Retries(RetryMode.DEFERRED)) as active_execution:
+    with plan.start(retry_mode=(RetryMode.DEFERRED)) as active_execution:
 
         steps = active_execution.get_steps_to_execute()
         assert len(steps) == 1
         step_1 = steps[0]
-        assert step_1.key == "return_two.compute"
+        assert step_1.key == "return_two"
 
         steps = active_execution.get_steps_to_execute()
         assert len(steps) == 0  # cant progress
@@ -231,17 +254,17 @@ def test_retries_deferred_active_execution():
 
         assert not active_execution.is_complete
 
-        steps = active_execution.get_steps_to_skip()
+        steps = active_execution.get_steps_to_abandon()
         # skip split of diamond
         assert len(steps) == 2
-        _ = [active_execution.mark_skipped(step.key) for step in steps]
+        _ = [active_execution.mark_abandoned(step.key) for step in steps]
 
         assert not active_execution.is_complete
 
-        steps = active_execution.get_steps_to_skip()
+        steps = active_execution.get_steps_to_abandon()
         # skip end of diamond
         assert len(steps) == 1
-        active_execution.mark_skipped(steps[0].key)
+        active_execution.mark_abandoned(steps[0].key)
 
         assert active_execution.is_complete
 
@@ -283,14 +306,14 @@ def test_priorities():
     sort_key_fn = lambda step: int(step.tags.get("priority", 0)) * -1
 
     plan = create_execution_plan(priorities)
-    with plan.start(Retries(RetryMode.DISABLED), sort_key_fn) as active_execution:
+    with plan.start(RetryMode.DISABLED, sort_key_fn) as active_execution:
         steps = active_execution.get_steps_to_execute()
-        assert steps[0].key == "pri_5.compute"
-        assert steps[1].key == "pri_4.compute"
-        assert steps[2].key == "pri_3.compute"
-        assert steps[3].key == "pri_2.compute"
-        assert steps[4].key == "pri_none.compute"
-        assert steps[5].key == "pri_neg_1.compute"
+        assert steps[0].key == "pri_5"
+        assert steps[1].key == "pri_4"
+        assert steps[2].key == "pri_3"
+        assert steps[3].key == "pri_2"
+        assert steps[4].key == "pri_none"
+        assert steps[5].key == "pri_neg_1"
         _ = [active_execution.mark_skipped(step.key) for step in steps]
 
 
@@ -310,8 +333,11 @@ def test_executor_not_created_for_execute_plan():
 def test_incomplete_execution_plan():
     plan = create_execution_plan(define_diamond_pipeline())
 
-    with pytest.raises(DagsterIncompleteExecutionPlanError):
-        with plan.start(retries=Retries(RetryMode.DISABLED)) as active_execution:
+    with pytest.raises(
+        DagsterInvariantViolationError,
+        match="Execution of pipeline finished without completing the execution plan.",
+    ):
+        with plan.start(retry_mode=(RetryMode.DISABLED)) as active_execution:
 
             steps = active_execution.get_steps_to_execute()
             assert len(steps) == 1
@@ -326,7 +352,7 @@ def test_lost_steps():
 
     # run to completion - but step was in unknown state so exception thrown
     with pytest.raises(DagsterUnknownStepStateError):
-        with plan.start(retries=Retries(RetryMode.DISABLED)) as active_execution:
+        with plan.start(retry_mode=(RetryMode.DISABLED)) as active_execution:
 
             steps = active_execution.get_steps_to_execute()
             assert len(steps) == 1
@@ -336,9 +362,172 @@ def test_lost_steps():
             active_execution.mark_unknown_state(step_1.key)
 
             # failure assumed for start step - so rest should skip
-            steps_to_skip = active_execution.get_steps_to_skip()
-            while steps_to_skip:
-                _ = [active_execution.mark_skipped(step.key) for step in steps_to_skip]
-                steps_to_skip = active_execution.get_steps_to_skip()
+            steps_to_abandon = active_execution.get_steps_to_abandon()
+            while steps_to_abandon:
+                _ = [active_execution.mark_abandoned(step.key) for step in steps_to_abandon]
+                steps_to_abandon = active_execution.get_steps_to_abandon()
 
             assert active_execution.is_complete
+
+
+def test_fan_out_should_skip_step():
+    @solid(
+        output_defs=[
+            OutputDefinition(Int, "out_1", is_required=False),
+            OutputDefinition(Int, "out_2", is_required=False),
+            OutputDefinition(Int, "out_3", is_required=False),
+        ]
+    )
+    def foo(_):
+        yield Output(1, "out_1")
+
+    @solid
+    def bar(_, input_arg):
+        return input_arg
+
+    @pipeline
+    def optional_outputs():
+        foo_res = foo()
+        # pylint: disable=no-member
+        bar.alias("bar_1")(input_arg=foo_res.out_1)
+        bar.alias("bar_2")(input_arg=foo_res.out_2)
+        bar.alias("bar_3")(input_arg=foo_res.out_3)
+
+    instance = DagsterInstance.ephemeral()
+    pipeline_run = PipelineRun(pipeline_name="optional_outputs", run_id=make_new_run_id())
+    execute_plan(
+        create_execution_plan(optional_outputs, step_keys_to_execute=["foo"]),
+        instance,
+        pipeline_run,
+    )
+
+    assert not should_skip_step(
+        create_execution_plan(optional_outputs, step_keys_to_execute=["bar_1"]),
+        instance,
+        pipeline_run.run_id,
+    )
+    assert should_skip_step(
+        create_execution_plan(optional_outputs, step_keys_to_execute=["bar_2"]),
+        instance,
+        pipeline_run.run_id,
+    )
+    assert should_skip_step(
+        create_execution_plan(optional_outputs, step_keys_to_execute=["bar_3"]),
+        instance,
+        pipeline_run.run_id,
+    )
+
+
+def test_fan_in_should_skip_step():
+    @lambda_solid
+    def one():
+        return 1
+
+    @solid(output_defs=[OutputDefinition(is_required=False)])
+    def skip(_):
+        return
+        yield  # pylint: disable=unreachable
+
+    @solid
+    def fan_in(_context, items):
+        return items
+
+    @composite_solid(output_defs=[OutputDefinition(is_required=False)])
+    def composite_all_upstream_skip():
+        return fan_in([skip(), skip()])
+
+    @composite_solid(output_defs=[OutputDefinition(is_required=False)])
+    def composite_one_upstream_skip():
+        return fan_in([one(), skip()])
+
+    @pipeline
+    def optional_outputs_composite():
+        composite_all_upstream_skip()
+        composite_one_upstream_skip()
+
+    instance = DagsterInstance.ephemeral()
+    pipeline_run = PipelineRun(pipeline_name="optional_outputs_composite", run_id=make_new_run_id())
+    execute_plan(
+        create_execution_plan(
+            optional_outputs_composite,
+            step_keys_to_execute=[
+                "composite_all_upstream_skip.skip",
+                "composite_all_upstream_skip.skip_2",
+            ],
+        ),
+        instance,
+        pipeline_run,
+    )
+    # skip when all the step's sources weren't yield
+    assert should_skip_step(
+        create_execution_plan(
+            optional_outputs_composite,
+            step_keys_to_execute=["composite_all_upstream_skip.fan_in"],
+        ),
+        instance,
+        pipeline_run.run_id,
+    )
+
+    execute_plan(
+        create_execution_plan(
+            optional_outputs_composite,
+            step_keys_to_execute=[
+                "composite_one_upstream_skip.one",
+                "composite_one_upstream_skip.skip",
+            ],
+        ),
+        instance,
+        pipeline_run,
+    )
+    # do not skip when some of the sources exist
+    assert not should_skip_step(
+        create_execution_plan(
+            optional_outputs_composite,
+            step_keys_to_execute=["composite_one_upstream_skip.fan_in"],
+        ),
+        instance,
+        pipeline_run.run_id,
+    )
+
+
+def test_configured_input_should_skip_step():
+    called = {}
+
+    @solid(output_defs=[OutputDefinition(is_required=False)])
+    def one(_):
+        yield Output(1)
+
+    @solid
+    def solid_should_not_skip(_, input_one, input_two):  # pylint: disable=unused-argument
+        called["yup"] = True
+
+    @pipeline
+    def my_pipeline():
+        solid_should_not_skip(one())
+
+    run_config = {"solids": {"solid_should_not_skip": {"inputs": {"input_two": {"value": "2"}}}}}
+    execute_pipeline(my_pipeline, run_config=run_config)
+    assert called.get("yup")
+
+    # ensure should_skip_step behave the same as execute_pipeline
+    instance = DagsterInstance.ephemeral()
+    pipeline_run = PipelineRun(pipeline_name="my_pipeline", run_id=make_new_run_id())
+    execute_plan(
+        create_execution_plan(
+            my_pipeline,
+            step_keys_to_execute=["one"],
+            run_config=run_config,
+        ),
+        instance,
+        pipeline_run,
+        run_config=run_config,
+    )
+    assert not should_skip_step(
+        create_execution_plan(
+            my_pipeline,
+            step_keys_to_execute=["solid_should_not_skip"],
+            run_config=run_config,
+        ),
+        instance,
+        pipeline_run.run_id,
+    )
