@@ -20,7 +20,7 @@ def composite_with_nested_config_solid():
 
 @pipeline
 def composite_pipeline():
-    return composite_with_nested_config_solid()
+    composite_with_nested_config_solid()
 
 
 @composite_solid(
@@ -36,7 +36,7 @@ def composite_with_nested_config_solid_and_config_mapping():
 
 @pipeline
 def composite_pipeline_with_config_mapping():
-    return composite_with_nested_config_solid_and_config_mapping()
+    composite_with_nested_config_solid_and_config_mapping()
 
 
 def test_execution_plan_for_composite_solid():
@@ -53,16 +53,24 @@ def test_execution_plan_for_composite_solid():
         pipeline_def=composite_pipeline, execution_plan=execution_plan
     )
     events = execute_plan(
-        execution_plan, run_config=run_config, pipeline_run=pipeline_run, instance=instance,
+        execution_plan,
+        run_config=run_config,
+        pipeline_run=pipeline_run,
+        instance=instance,
     )
 
     assert [e.event_type_value for e in events] == [
+        "ENGINE_EVENT",
+        "ENGINE_EVENT",
         "STEP_START",
         "STEP_OUTPUT",
+        "HANDLED_OUTPUT",
         "STEP_SUCCESS",
         "STEP_START",
+        "LOADED_INPUT",
         "STEP_INPUT",
         "STEP_OUTPUT",
+        "HANDLED_OUTPUT",
         "STEP_SUCCESS",
     ]
 
@@ -84,15 +92,23 @@ def test_execution_plan_for_composite_solid_with_config_mapping():
     )
 
     events = execute_plan(
-        execution_plan, run_config=run_config, pipeline_run=pipeline_run, instance=instance,
+        execution_plan,
+        run_config=run_config,
+        pipeline_run=pipeline_run,
+        instance=instance,
     )
 
     assert [e.event_type_value for e in events] == [
+        "ENGINE_EVENT",
+        "ENGINE_EVENT",
         "STEP_START",
         "STEP_OUTPUT",
+        "HANDLED_OUTPUT",
         "STEP_SUCCESS",
         "STEP_START",
+        "LOADED_INPUT",
         "STEP_INPUT",
         "STEP_OUTPUT",
+        "HANDLED_OUTPUT",
         "STEP_SUCCESS",
     ]
