@@ -1,10 +1,10 @@
 import os
+import tempfile
 import time
 import uuid
 from threading import Thread
 
 import pytest
-
 from dagster import (
     Field,
     ModeDefinition,
@@ -15,10 +15,10 @@ from dagster import (
     pipeline,
     reconstructable,
     resource,
-    seven,
     solid,
 )
 from dagster.core.definitions.no_step_launcher import no_step_launcher
+from dagster.core.errors import DagsterExecutionInterruptedError
 from dagster.core.events import DagsterEventType
 from dagster.core.execution.api import create_execution_plan
 from dagster.core.execution.context_creation_pipeline import PipelineExecutionContextManager
@@ -28,7 +28,6 @@ from dagster.core.execution.plan.external_step import (
     step_context_to_step_run_ref,
     step_run_ref_to_step_context,
 )
-from dagster.core.execution.retries import Retries, RetryMode
 from dagster.core.instance import DagsterInstance
 from dagster.core.storage.pipeline_run import PipelineRun
 from dagster.utils import safe_tempfile_path, send_interrupt
@@ -49,7 +48,7 @@ def make_run_config(scratch_dir, mode):
                 step_launcher_resource_key: {"config": {"scratch_dir": scratch_dir}}
                 for step_launcher_resource_key in step_launcher_resource_keys
             },
-            "storage": {"filesystem": {"config": {"base_dir": scratch_dir}}},
+            "intermediate_storage": {"filesystem": {"config": {"base_dir": scratch_dir}}},
         },
     )
 
@@ -126,7 +125,10 @@ def define_sleepy_pipeline():
     @pipeline(
         mode_defs=[
             ModeDefinition(
-                "external", resource_defs={"first_step_launcher": local_external_step_launcher,},
+                "external",
+                resource_defs={
+                    "first_step_launcher": local_external_step_launcher,
+                },
             ),
         ]
     )
@@ -149,13 +151,16 @@ def initialize_step_context(scratch_dir, instance):
     )
 
     initialization_manager = PipelineExecutionContextManager(
-        plan, pipeline_run.run_config, pipeline_run, instance,
+        plan,
+        pipeline_run.run_config,
+        pipeline_run,
+        instance,
     )
     for _ in initialization_manager.prepare_context():
         pass
     pipeline_context = initialization_manager.get_context()
 
-    step_context = pipeline_context.for_step(plan.get_step_by_key("return_two.compute"))
+    step_context = pipeline_context.for_step(plan.get_step_by_key("return_two"))
     return step_context
 
 
@@ -171,7 +176,6 @@ def test_step_context_to_step_run_ref():
         assert rehydrated_step_context.required_resource_keys == step_context.required_resource_keys
         rehydrated_step = rehydrated_step_context.step
         assert rehydrated_step.pipeline_name == step.pipeline_name
-        assert rehydrated_step.key_suffix == step.key_suffix
         assert rehydrated_step.step_inputs == step.step_inputs
         assert rehydrated_step.step_outputs == step.step_outputs
         assert rehydrated_step.kind == step.kind
@@ -181,7 +185,7 @@ def test_step_context_to_step_run_ref():
 
 
 def test_local_external_step_launcher():
-    with seven.TemporaryDirectory() as tmpdir:
+    with tempfile.TemporaryDirectory() as tmpdir:
         with DagsterInstance.ephemeral() as instance:
             step_context = initialize_step_context(tmpdir, instance)
 
@@ -195,7 +199,7 @@ def test_local_external_step_launcher():
 
 @pytest.mark.parametrize("mode", ["external", "internal_and_external"])
 def test_pipeline(mode):
-    with seven.TemporaryDirectory() as tmpdir:
+    with tempfile.TemporaryDirectory() as tmpdir:
         result = execute_pipeline(
             pipeline=reconstructable(define_basic_pipeline),
             mode=mode,
@@ -207,7 +211,7 @@ def test_pipeline(mode):
 
 def test_launcher_requests_retry():
     mode = "request_retry"
-    with seven.TemporaryDirectory() as tmpdir:
+    with tempfile.TemporaryDirectory() as tmpdir:
         result = execute_pipeline(
             pipeline=reconstructable(define_basic_pipeline),
             mode=mode,
@@ -231,13 +235,11 @@ def _send_interrupt_thread(temp_file):
 
 @pytest.mark.parametrize("mode", ["external"])
 def test_interrupt_step_launcher(mode):
-    with seven.TemporaryDirectory() as tmpdir:
-
+    with tempfile.TemporaryDirectory() as tmpdir:
         with safe_tempfile_path() as success_tempfile:
-
             sleepy_run_config = {
                 "resources": {"first_step_launcher": {"config": {"scratch_dir": tmpdir}}},
-                "storage": {"filesystem": {"config": {"base_dir": tmpdir}}},
+                "intermediate_storage": {"filesystem": {"config": {"base_dir": tmpdir}}},
                 "solids": {"sleepy_solid": {"config": {"tempfile": success_tempfile}}},
             }
 
@@ -247,6 +249,8 @@ def test_interrupt_step_launcher(mode):
 
             results = []
 
+            received_interrupt = False
+
             try:
                 for result in execute_pipeline_iterator(
                     pipeline=reconstructable(define_sleepy_pipeline),
@@ -254,11 +258,33 @@ def test_interrupt_step_launcher(mode):
                     run_config=sleepy_run_config,
                 ):
                     results.append(result.event_type)
-                assert False
-            except KeyboardInterrupt:
-                pass
+            except DagsterExecutionInterruptedError:
+                received_interrupt = True
+
+            assert received_interrupt
 
             assert DagsterEventType.STEP_FAILURE in results
             assert DagsterEventType.PIPELINE_FAILURE in results
 
             interrupt_thread.join()
+
+
+def test_multiproc_launcher_requests_retry():
+    mode = "request_retry"
+    with tempfile.TemporaryDirectory() as tmpdir:
+        run_config = make_run_config(tmpdir, mode)
+        run_config["execution"] = {"multiprocess": {}}
+        result = execute_pipeline(
+            instance=DagsterInstance.local_temp(tmpdir),
+            pipeline=reconstructable(define_basic_pipeline),
+            mode=mode,
+            run_config=run_config,
+        )
+        assert result.success
+        assert result.result_for_solid("return_two").output_value() == 2
+        assert result.result_for_solid("add_one").output_value() == 3
+        for step_key, events in result.events_by_step_key.items():
+            if step_key:
+                event_types = [event.event_type for event in events]
+                assert DagsterEventType.STEP_UP_FOR_RETRY in event_types
+                assert DagsterEventType.STEP_RESTARTED in event_types
