@@ -1,5 +1,4 @@
 import pytest
-
 from dagster import (
     AssetMaterialization,
     CompositeSolidDefinition,
@@ -21,6 +20,7 @@ from dagster import (
     usable_as_dagster_type,
 )
 from dagster.core.definitions.pipeline_base import InMemoryPipeline
+from dagster.core.errors import DagsterInvalidDefinitionError
 from dagster.core.execution.api import execute_run
 from dagster.core.storage.type_storage import TypeStoragePlugin
 from dagster.core.types.dagster_type import create_any_type
@@ -45,7 +45,16 @@ def get_resource_init_pipeline(resources_initted):
     def consumes_resource_b(context):
         assert context.resources.b == "B"
 
-    @pipeline(mode_defs=[ModeDefinition(resource_defs={"a": resource_a, "b": resource_b,})],)
+    @pipeline(
+        mode_defs=[
+            ModeDefinition(
+                resource_defs={
+                    "a": resource_a,
+                    "b": resource_b,
+                }
+            )
+        ],
+    )
     def selective_init_test_pipeline():
         consumes_resource_a()
         consumes_resource_b()
@@ -129,7 +138,8 @@ def test_execution_plan_subset_strict_resources():
     pipeline_def = get_resource_init_pipeline(resources_initted)
 
     pipeline_run = instance.create_run_for_pipeline(
-        pipeline_def, step_keys_to_execute=["consumes_resource_b.compute"],
+        pipeline_def,
+        step_keys_to_execute=["consumes_resource_b"],
     )
 
     result = execute_run(InMemoryPipeline(pipeline_def), pipeline_run, instance)
@@ -173,7 +183,16 @@ def test_solid_selection_with_aliases_strict_resources():
     def consumes_resource_b(context):
         assert context.resources.b == "B"
 
-    @pipeline(mode_defs=[ModeDefinition(resource_defs={"a": resource_a, "b": resource_b,})],)
+    @pipeline(
+        mode_defs=[
+            ModeDefinition(
+                resource_defs={
+                    "a": resource_a,
+                    "b": resource_b,
+                }
+            )
+        ],
+    )
     def selective_init_test_pipeline():
         consumes_resource_a.alias("alias_for_a")()
         consumes_resource_b()
@@ -220,7 +239,16 @@ def create_composite_solid_pipeline(resources_initted):
         consumes_resource_b()
         consumes_resource_b_error()
 
-    @pipeline(mode_defs=[ModeDefinition(resource_defs={"a": resource_a, "b": resource_b,})],)
+    @pipeline(
+        mode_defs=[
+            ModeDefinition(
+                resource_defs={
+                    "a": resource_a,
+                    "b": resource_b,
+                }
+            )
+        ],
+    )
     def selective_init_composite_test_pipeline():
         wraps_a()
         wraps_b()
@@ -248,7 +276,8 @@ def test_execution_plan_subset_strict_resources_within_composite():
     instance = DagsterInstance.ephemeral()
 
     pipeline_run = instance.create_run_for_pipeline(
-        pipeline_def, step_keys_to_execute=["wraps_b.consumes_resource_b.compute"],
+        pipeline_def,
+        step_keys_to_execute=["wraps_b.consumes_resource_b"],
     )
 
     result = execute_run(InMemoryPipeline(pipeline_def), pipeline_run, instance)
@@ -290,7 +319,16 @@ def test_execution_plan_subset_with_aliases():
     def consumes_resource_b(context):
         assert context.resources.b == "B"
 
-    @pipeline(mode_defs=[ModeDefinition(resource_defs={"a": resource_a, "b": resource_b,})],)
+    @pipeline(
+        mode_defs=[
+            ModeDefinition(
+                resource_defs={
+                    "a": resource_a,
+                    "b": resource_b,
+                }
+            )
+        ],
+    )
     def selective_init_test_pipeline_with_alias():
         consumes_resource_a()
         consumes_resource_b.alias("b_alias")()
@@ -298,7 +336,8 @@ def test_execution_plan_subset_with_aliases():
     instance = DagsterInstance.ephemeral()
 
     pipeline_run = instance.create_run_for_pipeline(
-        selective_init_test_pipeline_with_alias, step_keys_to_execute=["b_alias.compute"],
+        selective_init_test_pipeline_with_alias,
+        step_keys_to_execute=["b_alias"],
     )
 
     result = execute_run(
@@ -387,14 +426,17 @@ def test_resource_dependent_hydration_with_selective_init():
 
 
 def define_plugin_pipeline(
-    should_require_resources=True, resources_initted=None, compatible_storage=True
+    should_require_resources=True,
+    resources_initted=None,
+    compatible_storage=True,
+    mode_defines_resource=True,
 ):
     if resources_initted is None:
         resources_initted = {}
 
     class CustomStoragePlugin(TypeStoragePlugin):  # pylint: disable=no-init
         @classmethod
-        def compatible_with_storage_def(cls, system_storage_def):
+        def compatible_with_storage_def(cls, _):
             return compatible_storage
 
         @classmethod
@@ -428,7 +470,12 @@ def define_plugin_pipeline(
     def output_solid(_context):
         return "hello"
 
-    @pipeline(mode_defs=[ModeDefinition(resource_defs={"a": resource_a})])
+    if mode_defines_resource:
+        mode_defs = [ModeDefinition(resource_defs={"a": resource_a})]
+    else:
+        mode_defs = [ModeDefinition()]
+
+    @pipeline(mode_defs=mode_defs)
     def plugin_pipeline():
         output_solid()
 
@@ -438,13 +485,15 @@ def define_plugin_pipeline(
 def test_custom_type_with_resource_dependent_storage_plugin():
     under_required_pipeline = define_plugin_pipeline(should_require_resources=False)
     with pytest.raises(DagsterUnknownResourceError):
-        execute_pipeline(under_required_pipeline, {"storage": {"filesystem": {}}})
+        execute_pipeline(under_required_pipeline, {"intermediate_storage": {"filesystem": {}}})
 
     resources_initted = {}
     sufficiently_required_pipeline = define_plugin_pipeline(
         should_require_resources=True, resources_initted=resources_initted
     )
-    assert execute_pipeline(sufficiently_required_pipeline, {"storage": {"filesystem": {}}}).success
+    assert execute_pipeline(
+        sufficiently_required_pipeline, {"intermediate_storage": {"filesystem": {}}}
+    ).success
     assert set(resources_initted.keys()) == set("a")
 
     resources_initted = {}
@@ -553,7 +602,8 @@ def test_custom_type_with_resource_dependent_composite_materialization():
     )
     with pytest.raises(DagsterUnknownResourceError):
         execute_pipeline(
-            under_required_pipeline, {"solids": {"wrap_solid": {"outputs": [{"result": "hello"}]}}},
+            under_required_pipeline,
+            {"solids": {"wrap_solid": {"outputs": [{"result": "hello"}]}}},
         )
 
     sufficiently_required_pipeline = define_composite_materialization_pipeline(
@@ -639,3 +689,79 @@ def test_resource_passed_version():
         pass
 
     assert passed_version_resource.version == "42"
+
+
+def test_type_missing_resource_fails():
+    def resource_based_type_check(context, value):
+        return context.resources.a == value
+
+    CustomType = DagsterType(
+        name="NeedsA",
+        type_check_fn=resource_based_type_check,
+        required_resource_keys={"a"},
+    )
+
+    @solid(output_defs=[OutputDefinition(CustomType, "custom_type")])
+    def custom_type_solid(_):
+        return "A"
+
+    with pytest.raises(DagsterInvalidDefinitionError, match='required by type "NeedsA"'):
+
+        @pipeline
+        def _type_check_pipeline():
+            custom_type_solid()
+
+
+def test_loader_missing_resource_fails():
+    @dagster_type_loader(String, required_resource_keys={"a"})
+    def InputHydration(context, hello):
+        assert context.resources.a == "A"
+        return CustomType(hello)
+
+    @usable_as_dagster_type(loader=InputHydration)
+    class CustomType(str):
+        pass
+
+    @solid(input_defs=[InputDefinition("_custom_type", CustomType)])
+    def custom_type_solid(_, _custom_type):
+        return "A"
+
+    with pytest.raises(
+        DagsterInvalidDefinitionError, match='required by the loader on type "CustomType"'
+    ):
+
+        @pipeline
+        def _type_check_pipeline():
+            custom_type_solid()
+
+
+def test_materialize_missing_resource_fails():
+    @dagster_type_materializer(String, required_resource_keys={"a"})
+    def materialize(context, *_args, **_kwargs):
+        assert context.resources.a == "A"
+        return AssetMaterialization("hello")
+
+    CustomType = create_any_type(name="CustomType", materializer=materialize)
+
+    @solid(output_defs=[OutputDefinition(CustomType, "custom_type")])
+    def custom_type_solid(_):
+        return "A"
+
+    with pytest.raises(
+        DagsterInvalidDefinitionError, match='required by the materializer on type "CustomType"'
+    ):
+
+        @pipeline
+        def _type_check_pipeline():
+            custom_type_solid()
+
+
+def test_plugin_missing_resource_fails():
+    with pytest.raises(
+        DagsterInvalidDefinitionError,
+        match=r'required by the plugin "CustomStoragePlugin" on type "CustomType" \(used with storages',
+    ):
+        define_plugin_pipeline(mode_defines_resource=False)
+
+    # works since storages are not compatible with plugin
+    define_plugin_pipeline(mode_defines_resource=False, compatible_storage=False)
