@@ -6,47 +6,20 @@ from snapshottest import Snapshot
 
 snapshots = Snapshot()
 
-snapshots['test_create_noop_execution_plan 1'] = '''{
-  "__class__": "ExecutionPlanSnapshot",
-  "artifacts_persisted": false,
-  "pipeline_snapshot_id": "5477a4bd4f8161b7ec6c72c54ca64196f25c8375",
-  "step_keys_to_execute": [
-    "noop_solid.compute"
-  ],
-  "steps": [
-    {
-      "__class__": "ExecutionStepSnap",
-      "inputs": [],
-      "key": "noop_solid.compute",
-      "kind": {
-        "__enum__": "StepKind.COMPUTE"
-      },
-      "metadata_items": [],
-      "outputs": [
-        {
-          "__class__": "ExecutionStepOutputSnap",
-          "dagster_type_key": "Any",
-          "name": "result"
-        }
-      ],
-      "solid_handle_id": "noop_solid"
-    }
-  ]
-}'''
-
 snapshots['test_create_execution_plan_with_dep 1'] = '''{
   "__class__": "ExecutionPlanSnapshot",
-  "artifacts_persisted": false,
-  "pipeline_snapshot_id": "b2dd058376d87ebf542b5b7cfaf0147812bc5dc7",
+  "artifacts_persisted": true,
+  "initial_known_state": null,
+  "pipeline_snapshot_id": "0baebbaa257331ddeaccd3076c3dca413e099cf4",
   "step_keys_to_execute": [
-    "solid_one.compute",
-    "solid_two.compute"
+    "solid_one",
+    "solid_two"
   ],
   "steps": [
     {
       "__class__": "ExecutionStepSnap",
       "inputs": [],
-      "key": "solid_one.compute",
+      "key": "solid_one",
       "kind": {
         "__enum__": "StepKind.COMPUTE"
       },
@@ -70,13 +43,14 @@ snapshots['test_create_execution_plan_with_dep 1'] = '''{
           "upstream_output_handles": [
             {
               "__class__": "StepOutputHandle",
+              "mapping_key": null,
               "output_name": "result",
-              "step_key": "solid_one.compute"
+              "step_key": "solid_one"
             }
           ]
         }
       ],
-      "key": "solid_two.compute",
+      "key": "solid_two",
       "kind": {
         "__enum__": "StepKind.COMPUTE"
       },
@@ -93,94 +67,19 @@ snapshots['test_create_execution_plan_with_dep 1'] = '''{
   ]
 }'''
 
-snapshots['test_create_with_composite 1'] = '''{
+snapshots['test_create_noop_execution_plan 1'] = '''{
   "__class__": "ExecutionPlanSnapshot",
-  "artifacts_persisted": false,
-  "pipeline_snapshot_id": "d129f62ffe58f1c9ba4655c14ba37f47cd6e47e3",
+  "artifacts_persisted": true,
+  "initial_known_state": null,
+  "pipeline_snapshot_id": "9dfe20d8e31bb905c15bacc012b4be684e78243a",
   "step_keys_to_execute": [
-    "comp_1.return_one.compute",
-    "comp_1.add_one.compute",
-    "comp_2.return_one.compute",
-    "comp_2.add_one.compute",
-    "add.compute"
+    "noop_solid"
   ],
   "steps": [
-    {
-      "__class__": "ExecutionStepSnap",
-      "inputs": [
-        {
-          "__class__": "ExecutionStepInputSnap",
-          "dagster_type_key": "Any",
-          "name": "num_one",
-          "upstream_output_handles": [
-            {
-              "__class__": "StepOutputHandle",
-              "output_name": "result",
-              "step_key": "comp_1.add_one.compute"
-            }
-          ]
-        },
-        {
-          "__class__": "ExecutionStepInputSnap",
-          "dagster_type_key": "Any",
-          "name": "num_two",
-          "upstream_output_handles": [
-            {
-              "__class__": "StepOutputHandle",
-              "output_name": "result",
-              "step_key": "comp_2.add_one.compute"
-            }
-          ]
-        }
-      ],
-      "key": "add.compute",
-      "kind": {
-        "__enum__": "StepKind.COMPUTE"
-      },
-      "metadata_items": [],
-      "outputs": [
-        {
-          "__class__": "ExecutionStepOutputSnap",
-          "dagster_type_key": "Any",
-          "name": "result"
-        }
-      ],
-      "solid_handle_id": "add"
-    },
-    {
-      "__class__": "ExecutionStepSnap",
-      "inputs": [
-        {
-          "__class__": "ExecutionStepInputSnap",
-          "dagster_type_key": "Int",
-          "name": "num",
-          "upstream_output_handles": [
-            {
-              "__class__": "StepOutputHandle",
-              "output_name": "out_num",
-              "step_key": "comp_1.return_one.compute"
-            }
-          ]
-        }
-      ],
-      "key": "comp_1.add_one.compute",
-      "kind": {
-        "__enum__": "StepKind.COMPUTE"
-      },
-      "metadata_items": [],
-      "outputs": [
-        {
-          "__class__": "ExecutionStepOutputSnap",
-          "dagster_type_key": "Int",
-          "name": "result"
-        }
-      ],
-      "solid_handle_id": "comp_1.add_one"
-    },
     {
       "__class__": "ExecutionStepSnap",
       "inputs": [],
-      "key": "comp_1.return_one.compute",
+      "key": "noop_solid",
       "kind": {
         "__enum__": "StepKind.COMPUTE"
       },
@@ -188,74 +87,28 @@ snapshots['test_create_with_composite 1'] = '''{
       "outputs": [
         {
           "__class__": "ExecutionStepOutputSnap",
-          "dagster_type_key": "Int",
-          "name": "out_num"
-        }
-      ],
-      "solid_handle_id": "comp_1.return_one"
-    },
-    {
-      "__class__": "ExecutionStepSnap",
-      "inputs": [
-        {
-          "__class__": "ExecutionStepInputSnap",
-          "dagster_type_key": "Int",
-          "name": "num",
-          "upstream_output_handles": [
-            {
-              "__class__": "StepOutputHandle",
-              "output_name": "out_num",
-              "step_key": "comp_2.return_one.compute"
-            }
-          ]
-        }
-      ],
-      "key": "comp_2.add_one.compute",
-      "kind": {
-        "__enum__": "StepKind.COMPUTE"
-      },
-      "metadata_items": [],
-      "outputs": [
-        {
-          "__class__": "ExecutionStepOutputSnap",
-          "dagster_type_key": "Int",
+          "dagster_type_key": "Any",
           "name": "result"
         }
       ],
-      "solid_handle_id": "comp_2.add_one"
-    },
-    {
-      "__class__": "ExecutionStepSnap",
-      "inputs": [],
-      "key": "comp_2.return_one.compute",
-      "kind": {
-        "__enum__": "StepKind.COMPUTE"
-      },
-      "metadata_items": [],
-      "outputs": [
-        {
-          "__class__": "ExecutionStepOutputSnap",
-          "dagster_type_key": "Int",
-          "name": "out_num"
-        }
-      ],
-      "solid_handle_id": "comp_2.return_one"
+      "solid_handle_id": "noop_solid"
     }
   ]
 }'''
 
 snapshots['test_create_noop_execution_plan_with_tags 1'] = '''{
   "__class__": "ExecutionPlanSnapshot",
-  "artifacts_persisted": false,
-  "pipeline_snapshot_id": "672b802381d5cced7964e8c95fa535d0d79cab6e",
+  "artifacts_persisted": true,
+  "initial_known_state": null,
+  "pipeline_snapshot_id": "3c29d0513af8e2ebfb301e3c1dd9ca66718c0f91",
   "step_keys_to_execute": [
-    "noop_solid.compute"
+    "noop_solid"
   ],
   "steps": [
     {
       "__class__": "ExecutionStepSnap",
       "inputs": [],
-      "key": "noop_solid.compute",
+      "key": "noop_solid",
       "kind": {
         "__enum__": "StepKind.COMPUTE"
       },
@@ -282,3 +135,159 @@ snapshots['test_create_noop_execution_plan_with_tags 1'] = '''{
     }
   ]
 }'''
+
+snapshots['test_create_with_composite 1'] = '''{
+  "__class__": "ExecutionPlanSnapshot",
+  "artifacts_persisted": true,
+  "initial_known_state": null,
+  "pipeline_snapshot_id": "9549e65e338684809d962c9e77276836bbab9842",
+  "step_keys_to_execute": [
+    "comp_1.return_one",
+    "comp_1.add_one",
+    "comp_2.return_one",
+    "comp_2.add_one",
+    "add"
+  ],
+  "steps": [
+    {
+      "__class__": "ExecutionStepSnap",
+      "inputs": [
+        {
+          "__class__": "ExecutionStepInputSnap",
+          "dagster_type_key": "Any",
+          "name": "num_one",
+          "upstream_output_handles": [
+            {
+              "__class__": "StepOutputHandle",
+              "mapping_key": null,
+              "output_name": "result",
+              "step_key": "comp_1.add_one"
+            }
+          ]
+        },
+        {
+          "__class__": "ExecutionStepInputSnap",
+          "dagster_type_key": "Any",
+          "name": "num_two",
+          "upstream_output_handles": [
+            {
+              "__class__": "StepOutputHandle",
+              "mapping_key": null,
+              "output_name": "result",
+              "step_key": "comp_2.add_one"
+            }
+          ]
+        }
+      ],
+      "key": "add",
+      "kind": {
+        "__enum__": "StepKind.COMPUTE"
+      },
+      "metadata_items": [],
+      "outputs": [
+        {
+          "__class__": "ExecutionStepOutputSnap",
+          "dagster_type_key": "Any",
+          "name": "result"
+        }
+      ],
+      "solid_handle_id": "add"
+    },
+    {
+      "__class__": "ExecutionStepSnap",
+      "inputs": [
+        {
+          "__class__": "ExecutionStepInputSnap",
+          "dagster_type_key": "Int",
+          "name": "num",
+          "upstream_output_handles": [
+            {
+              "__class__": "StepOutputHandle",
+              "mapping_key": null,
+              "output_name": "out_num",
+              "step_key": "comp_1.return_one"
+            }
+          ]
+        }
+      ],
+      "key": "comp_1.add_one",
+      "kind": {
+        "__enum__": "StepKind.COMPUTE"
+      },
+      "metadata_items": [],
+      "outputs": [
+        {
+          "__class__": "ExecutionStepOutputSnap",
+          "dagster_type_key": "Int",
+          "name": "result"
+        }
+      ],
+      "solid_handle_id": "comp_1.add_one"
+    },
+    {
+      "__class__": "ExecutionStepSnap",
+      "inputs": [],
+      "key": "comp_1.return_one",
+      "kind": {
+        "__enum__": "StepKind.COMPUTE"
+      },
+      "metadata_items": [],
+      "outputs": [
+        {
+          "__class__": "ExecutionStepOutputSnap",
+          "dagster_type_key": "Int",
+          "name": "out_num"
+        }
+      ],
+      "solid_handle_id": "comp_1.return_one"
+    },
+    {
+      "__class__": "ExecutionStepSnap",
+      "inputs": [
+        {
+          "__class__": "ExecutionStepInputSnap",
+          "dagster_type_key": "Int",
+          "name": "num",
+          "upstream_output_handles": [
+            {
+              "__class__": "StepOutputHandle",
+              "mapping_key": null,
+              "output_name": "out_num",
+              "step_key": "comp_2.return_one"
+            }
+          ]
+        }
+      ],
+      "key": "comp_2.add_one",
+      "kind": {
+        "__enum__": "StepKind.COMPUTE"
+      },
+      "metadata_items": [],
+      "outputs": [
+        {
+          "__class__": "ExecutionStepOutputSnap",
+          "dagster_type_key": "Int",
+          "name": "result"
+        }
+      ],
+      "solid_handle_id": "comp_2.add_one"
+    },
+    {
+      "__class__": "ExecutionStepSnap",
+      "inputs": [],
+      "key": "comp_2.return_one",
+      "kind": {
+        "__enum__": "StepKind.COMPUTE"
+      },
+      "metadata_items": [],
+      "outputs": [
+        {
+          "__class__": "ExecutionStepOutputSnap",
+          "dagster_type_key": "Int",
+          "name": "out_num"
+        }
+      ],
+      "solid_handle_id": "comp_2.return_one"
+    }
+  ]
+}'''
