@@ -10,6 +10,7 @@ from dagster import (
     OutputDefinition,
     PipelineDefinition,
     ResourceDefinition,
+    Shape,
     SolidDefinition,
     SolidInvocation,
     String,
@@ -23,10 +24,9 @@ from dagster.config.validate import process_config
 from dagster.core.definitions import create_environment_type, create_run_config_schema
 from dagster.core.definitions.environment_configs import (
     EnvironmentClassCreationData,
-    define_solid_config_cls,
     define_solid_dictionary_cls,
 )
-from dagster.core.system_config.objects import EnvironmentConfig, SolidConfig
+from dagster.core.system_config.objects import EnvironmentConfig, ResourceConfig, SolidConfig
 from dagster.loggers import default_loggers
 
 
@@ -37,6 +37,7 @@ def create_creation_data(pipeline_def):
         pipeline_def.dependency_structure,
         pipeline_def.mode_definition,
         logger_defs=default_loggers(),
+        ignored_solids=[],
     )
 
 
@@ -105,7 +106,10 @@ def test_provided_default_on_resources_config():
     assert some_resource_field.default_value == {"config": {"with_default_int": 23434}}
 
     value = EnvironmentConfig.build(pipeline_def, {})
-    assert value.resources == {"some_resource": {"config": {"with_default_int": 23434}}}
+    assert value.resources == {
+        "some_resource": ResourceConfig({"with_default_int": 23434}),
+        "io_manager": ResourceConfig(None),
+    }
 
 
 def test_default_environment():
@@ -121,7 +125,7 @@ def test_default_environment():
 
 
 def test_solid_config():
-    solid_config_type = define_solid_config_cls(Field(Int), None, None)
+    solid_config_type = Shape({"config": Field(Int)})
     solid_inst = process_config(solid_config_type, {"config": 1})
     assert solid_inst.value["config"] == 1
 
@@ -131,13 +135,18 @@ def test_solid_dictionary_type():
 
     env_obj = EnvironmentConfig.build(
         pipeline_def,
-        {"solids": {"int_config_solid": {"config": 1}, "string_config_solid": {"config": "bar"}},},
+        {
+            "solids": {"int_config_solid": {"config": 1}, "string_config_solid": {"config": "bar"}},
+        },
     )
 
     value = env_obj.solids
 
     assert set(["int_config_solid", "string_config_solid"]) == set(value.keys())
-    assert value == {"int_config_solid": SolidConfig(1), "string_config_solid": SolidConfig("bar")}
+    assert value == {
+        "int_config_solid": SolidConfig.from_dict({"config": 1}),
+        "string_config_solid": SolidConfig.from_dict({"config": "bar"}),
+    }
 
 
 def define_test_solids_config_pipeline():
@@ -210,7 +219,10 @@ def test_solid_dictionary_some_no_config():
     env = EnvironmentConfig.build(pipeline_def, {"solids": {"int_config_solid": {"config": 1}}})
 
     assert {"int_config_solid", "no_config_solid"} == set(env.solids.keys())
-    assert env.solids == {"int_config_solid": SolidConfig(1), "no_config_solid": SolidConfig()}
+    assert env.solids == {
+        "int_config_solid": SolidConfig.from_dict({"config": 1}),
+        "no_config_solid": SolidConfig.from_dict({}),
+    }
 
 
 def test_whole_environment():
@@ -249,21 +261,28 @@ def test_whole_environment():
     )
 
     assert isinstance(env, EnvironmentConfig)
-    assert env.solids == {"int_config_solid": SolidConfig(123), "no_config_solid": SolidConfig()}
-    assert env.resources == {"test_resource": {"config": 1}}
+    assert env.solids == {
+        "int_config_solid": SolidConfig.from_dict({"config": 123}),
+        "no_config_solid": SolidConfig.from_dict({}),
+    }
+    assert env.resources == {"test_resource": ResourceConfig(1), "io_manager": ResourceConfig(None)}
 
 
 def test_solid_config_error():
     pipeline_def = define_test_solids_config_pipeline()
     solid_dict_type = define_solid_dictionary_cls(
-        pipeline_def.solids, pipeline_def.dependency_structure,
+        solids=pipeline_def.solids,
+        ignored_solids=None,
+        dependency_structure=pipeline_def.dependency_structure,
+        parent_handle=None,
+        resource_defs={},
     )
 
     int_solid_config_type = solid_dict_type.fields["int_config_solid"].config_type
 
     res = process_config(int_solid_config_type, {"notconfig": 1})
     assert not res.success
-    assert re.match('Undefined field "notconfig"', res.errors[0].message)
+    assert re.match('Received unexpected config entry "notconfig"', res.errors[0].message)
 
     res = process_config(int_solid_config_type, 1)
     assert not res.success
@@ -388,7 +407,8 @@ def test_required_solid_with_required_subfield():
     assert env_type.fields["execution"].is_required is False
 
     env_obj = EnvironmentConfig.build(
-        pipeline_def, {"solids": {"int_config_solid": {"config": {"required_field": "foobar"}}}},
+        pipeline_def,
+        {"solids": {"int_config_solid": {"config": {"required_field": "foobar"}}}},
     )
 
     assert env_obj.solids["int_config_solid"].config["required_field"] == "foobar"
@@ -440,7 +460,8 @@ def test_required_resource_with_required_subfield():
             ModeDefinition(
                 resource_defs={
                     "with_required": ResourceDefinition(
-                        resource_fn=lambda _: None, config_schema={"required_field": String},
+                        resource_fn=lambda _: None,
+                        config_schema={"required_field": String},
                     )
                 }
             )
@@ -499,7 +520,8 @@ def test_optional_and_required_context():
                         config_schema={"optional_field": Field(String, is_required=False)},
                     ),
                     "required_resource": ResourceDefinition(
-                        lambda _: None, config_schema={"required_field": String},
+                        lambda _: None,
+                        config_schema={"required_field": String},
                     ),
                 },
             )
@@ -528,12 +550,14 @@ def test_optional_and_required_context():
     ).is_required
 
     env_obj = EnvironmentConfig.build(
-        pipeline_def, {"resources": {"required_resource": {"config": {"required_field": "foo"}}}},
+        pipeline_def,
+        {"resources": {"required_resource": {"config": {"required_field": "foo"}}}},
     )
 
     assert env_obj.resources == {
-        "optional_resource": {"config": {}},
-        "required_resource": {"config": {"required_field": "foo"}},
+        "optional_resource": ResourceConfig({}),
+        "required_resource": ResourceConfig({"required_field": "foo"}),
+        "io_manager": ResourceConfig(None),
     }
 
 
@@ -614,10 +638,10 @@ def test_storage_in_memory_config():
     env_type = create_environment_type(pipeline_def)
     assert "storage" in env_type.fields
 
-    config_value = process_config(env_type, {"storage": {"in_memory": {}}})
+    config_value = process_config(env_type, {"intermediate_storage": {"in_memory": {}}})
     assert config_value.success
 
-    assert config_value.value["storage"] == {"in_memory": {}}
+    assert config_value.value["intermediate_storage"] == {"in_memory": {}}
 
 
 def test_directly_init_environment_config():
