@@ -4,12 +4,12 @@ import re
 from contextlib import contextmanager
 
 import pytest
-
 from dagster import ModeDefinition, check, execute_solid, pipeline, resource, solid
 from dagster.core.definitions import SolidHandle
 from dagster.core.events import DagsterEvent
 from dagster.core.execution.context.logger import InitLoggerContext
 from dagster.core.execution.plan.objects import StepFailureData
+from dagster.core.execution.plan.outputs import StepOutputHandle
 from dagster.core.log_manager import DagsterLogManager
 from dagster.loggers import colored_console_logger, json_console_logger
 from dagster.utils.error import SerializableErrorInfo
@@ -106,7 +106,7 @@ def test_multiline_logging_complex():
     msg = "DagsterEventType.STEP_FAILURE for step start.materialization.output.result.0"
     kwargs = {
         "pipeline": "example",
-        "pipeline_name": "example",
+        "pipeline_name": "error_monster",
         "step_key": "start.materialization.output.result.0",
         "solid": "start",
         "solid_definition": "emit_num",
@@ -141,15 +141,10 @@ def test_multiline_logging_complex():
     expected_results = [
         "error_monster - 123 - STEP_FAILURE - DagsterEventType.STEP_FAILURE for step "
         "start.materialization.output.result.0",
-        '            cls_name = "FileNotFoundError"',
-        '       error_message = "FileNotFoundError: [Errno 2] No such file or directory:'
-        " '/path/to/file'\\n\"",
-        '               solid = "start"',
-        '    solid_definition = "emit_num"',
-        '            step_key = "start.materialization.output.result.0"',
         "",
         "FileNotFoundError: [Errno 2] No such file or directory: '/path/to/file'",
         "",
+        "Stack Trace:",
         "a stack message",
     ]
 
@@ -176,7 +171,11 @@ def test_colored_console_logger_with_integer_log_level():
         pass
 
     colored_console_logger.logger_fn(
-        InitLoggerContext({"name": "dagster", "log_level": 4}, pipe, colored_console_logger, "")
+        InitLoggerContext(
+            {"name": "dagster", "log_level": 4},
+            colored_console_logger,
+            pipeline_def=pipe,
+        )
     )
 
 
@@ -224,16 +223,36 @@ def test_resource_logging(capsys):
         context.resources.bar()
 
     execute_solid(
-        process, mode_def=ModeDefinition(resource_defs={"foo": foo_resource, "bar": bar_resource}),
+        process,
+        mode_def=ModeDefinition(resource_defs={"foo": foo_resource, "bar": bar_resource}),
     )
 
     captured = capsys.readouterr()
 
     expected_log_regexes = [
         r"dagster - INFO - resource:foo - [a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-"
-        r'[a-f0-9]{12} - test logging from foo resource\n\s*resource_fn_name = "foo_resource"',
+        r"[a-f0-9]{12} - process - test logging from foo resource",
         r"dagster - INFO - resource:bar - [a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-"
-        r'[a-f0-9]{12} - test logging from bar resource\n\s*resource_fn_name = "bar_resource"',
+        r"[a-f0-9]{12} - process - test logging from bar resource",
     ]
     for expected_log_regex in expected_log_regexes:
         assert re.search(expected_log_regex, captured.err, re.MULTILINE)
+
+
+def test_io_context_logging(capsys):
+    @solid
+    def logged_solid(context):
+        context.get_system_context().get_output_context(
+            StepOutputHandle("logged_solid", "result")
+        ).log.debug("test OUTPUT debug logging from logged_solid.")
+        context.get_system_context().for_input_manager(
+            "logged_solid", {}, {}, None, source_handle=None
+        ).log.debug("test INPUT debug logging from logged_solid.")
+
+    result = execute_solid(logged_solid)
+    assert result.success
+
+    captured = capsys.readouterr()
+
+    assert re.search("test OUTPUT debug logging from logged_solid.", captured.err, re.MULTILINE)
+    assert re.search("test INPUT debug logging from logged_solid.", captured.err, re.MULTILINE)
