@@ -1,11 +1,7 @@
-import re
 import uuid
 
 import pytest
-
 from dagster import (
-    DagsterExecutionStepNotFoundError,
-    DagsterInvariantViolationError,
     DependencyDefinition,
     InputDefinition,
     Int,
@@ -27,14 +23,14 @@ from dagster import (
     reexecute_pipeline,
     solid,
 )
-from dagster.cli.workspace.load import location_handle_from_python_file
+from dagster.cli.workspace.load import location_origin_from_python_file
 from dagster.core.definitions import Solid
 from dagster.core.definitions.dependency import DependencyStructure
-from dagster.core.definitions.solid_container import _create_adjacency_lists
+from dagster.core.definitions.graph import _create_adjacency_lists
+from dagster.core.errors import DagsterExecutionStepNotFoundError, DagsterInvariantViolationError
 from dagster.core.execution.results import SolidExecutionResult
-from dagster.core.host_representation import RepositoryLocation, UserProcessApi
 from dagster.core.instance import DagsterInstance
-from dagster.core.test_utils import step_output_event_filter
+from dagster.core.test_utils import instance_for_test, step_output_event_filter
 from dagster.core.utility_solids import (
     create_root_solid,
     create_solid_with_deps,
@@ -76,7 +72,10 @@ def make_compute_fn():
 
 
 def _do_construct(solids, dependencies):
-    solids = {s.name: Solid(name=s.name, definition=s) for s in solids}
+    pipeline_def = PipelineDefinition(name="test", solid_defs=solids, dependencies=dependencies)
+    solids = {
+        s.name: Solid(name=s.name, definition=s, graph_definition=pipeline_def) for s in solids
+    }
     dependency_structure = DependencyStructure.from_definitions(solids, dependencies)
     return _create_adjacency_lists(list(solids.values()), dependency_structure)
 
@@ -166,23 +165,21 @@ def test_diamond_toposort():
 
 
 def test_external_diamond_toposort():
-    repo_location = RepositoryLocation.from_handle(
-        location_handle_from_python_file(
-            python_file=__file__,
-            attribute="create_diamond_pipeline",
-            working_directory=None,
-            user_process_api=UserProcessApi.CLI,
-        )
-    )
-    external_repo = next(iter(repo_location.get_repositories().values()))
-    external_pipeline = next(iter(external_repo.get_all_external_pipelines()))
-    assert external_pipeline.solid_names_in_topological_order == [
-        "A_source",
-        "A",
-        "B",
-        "C",
-        "D",
-    ]
+    with location_origin_from_python_file(
+        python_file=__file__,
+        attribute="create_diamond_pipeline",
+        working_directory=None,
+    ).create_handle() as handle:
+        repo_location = handle.create_location()
+        external_repo = next(iter(repo_location.get_repositories().values()))
+        external_pipeline = next(iter(external_repo.get_all_external_pipelines()))
+        assert external_pipeline.solid_names_in_topological_order == [
+            "A_source",
+            "A",
+            "B",
+            "C",
+            "D",
+        ]
 
 
 def compute_called(name):
@@ -208,7 +205,9 @@ def assert_all_results_equivalent(expected_results, result_results):
 
 
 def test_pipeline_execution_graph_diamond():
-    pipe = PipelineDefinition(solid_defs=create_diamond_solids(), dependencies=diamond_deps())
+    pipe = PipelineDefinition(
+        solid_defs=create_diamond_solids(), name="test", dependencies=diamond_deps()
+    )
     return _do_test(pipe)
 
 
@@ -271,7 +270,7 @@ def test_two_root_solid_pipeline_with_partial_dependency_definition():
     stub_solid_b = define_stub_solid("stub_b", [{"a key": "a value"}])
 
     single_dep_pipe = PipelineDefinition(
-        solid_defs=[stub_solid_a, stub_solid_b], dependencies={"stub_a": {}}
+        solid_defs=[stub_solid_a, stub_solid_b], name="test", dependencies={"stub_a": {}}
     )
 
     assert execute_pipeline(single_dep_pipe).success
@@ -313,7 +312,7 @@ def _do_test(pipe):
 
 
 def test_empty_pipeline_execution():
-    result = execute_pipeline(PipelineDefinition(solid_defs=[]))
+    result = execute_pipeline(PipelineDefinition(solid_defs=[], name="test"))
 
     assert result.success
 
@@ -323,7 +322,7 @@ def test_pipeline_name_threaded_through_context():
 
     @solid()
     def assert_name_solid(context):
-        assert context.pipeline_def.name == name
+        assert context.pipeline_name == name
 
     result = execute_pipeline(PipelineDefinition(name="foobar", solid_defs=[assert_name_solid]))
 
@@ -341,6 +340,7 @@ def test_pipeline_subset():
 
     pipeline_def = PipelineDefinition(
         solid_defs=[return_one, add_one],
+        name="test",
         dependencies={"add_one": {"num": DependencyDefinition("return_one")}},
     )
 
@@ -370,6 +370,7 @@ def test_pipeline_explicit_subset():
 
     pipeline_def = PipelineDefinition(
         solid_defs=[return_one, add_one],
+        name="test",
         dependencies={"add_one": {"num": DependencyDefinition("return_one")}},
     )
 
@@ -439,6 +440,7 @@ def test_pipeline_subset_with_multi_dependency():
 
     pipeline_def = PipelineDefinition(
         solid_defs=[return_one, return_two, noop],
+        name="test",
         dependencies={
             "noop": {
                 "dep": MultiDependencyDefinition(
@@ -482,6 +484,7 @@ def test_pipeline_explicit_subset_with_multi_dependency():
 
     pipeline_def = PipelineDefinition(
         solid_defs=[return_one, return_two, noop],
+        name="test",
         dependencies={
             "noop": {
                 "dep": MultiDependencyDefinition(
@@ -582,7 +585,8 @@ def test_pipeline_wrapping_types():
     ).success
 
     assert execute_pipeline(
-        wrapping_test, run_config={"solids": {"double_string_for_all": {"inputs": {"value": []}}}},
+        wrapping_test,
+        run_config={"solids": {"double_string_for_all": {"inputs": {"value": []}}}},
     ).success
 
     assert execute_pipeline(
@@ -677,14 +681,32 @@ def test_pipeline_init_failure():
     def failing_init_pipeline():
         stub_solid()
 
+    mem_instance = DagsterInstance.ephemeral()
     result = execute_pipeline(
-        failing_init_pipeline, run_config=dict(env_config), raise_on_error=False
+        failing_init_pipeline,
+        run_config=dict(env_config),
+        raise_on_error=False,
+        instance=mem_instance,
     )
 
     assert result.success is False
     event = result.event_list[-1]
     assert event.event_type_value == "PIPELINE_INIT_FAILURE"
     assert event.pipeline_init_failure_data
+    assert mem_instance.get_run_by_id(result.run_id).is_failure
+
+    with instance_for_test() as fs_instance:
+        result = execute_pipeline(
+            failing_init_pipeline,
+            run_config=dict(env_config),
+            raise_on_error=False,
+            instance=fs_instance,
+        )
+        assert result.success is False
+        event = result.event_list[-1]
+        assert event.event_type_value == "PIPELINE_INIT_FAILURE"
+        assert event.pipeline_init_failure_data
+        assert fs_instance.get_run_by_id(result.run_id).is_failure
 
 
 def test_reexecution_fs_storage():
@@ -698,6 +720,7 @@ def test_reexecution_fs_storage():
 
     pipeline_def = PipelineDefinition(
         solid_defs=[return_one, add_one],
+        name="test",
         dependencies={"add_one": {"num": DependencyDefinition("return_one")}},
     )
     run_config = {"storage": {"filesystem": {}}}
@@ -709,7 +732,10 @@ def test_reexecution_fs_storage():
     assert pipeline_result.result_for_solid("add_one").output_value() == 2
 
     reexecution_result = reexecute_pipeline(
-        pipeline_def, pipeline_result.run_id, run_config=run_config, instance=instance,
+        pipeline_def,
+        pipeline_result.run_id,
+        run_config=run_config,
+        instance=instance,
     )
 
     assert reexecution_result.success
@@ -721,7 +747,10 @@ def test_reexecution_fs_storage():
     assert reexecution_run.root_run_id == pipeline_result.run_id
 
     grandchild_result = reexecute_pipeline(
-        pipeline_def, reexecution_result.run_id, run_config=run_config, instance=instance,
+        pipeline_def,
+        reexecution_result.run_id,
+        run_config=run_config,
+        instance=instance,
     )
 
     assert grandchild_result.success
@@ -744,6 +773,7 @@ def test_reexecution_fs_storage_with_solid_selection():
 
     pipeline_def = PipelineDefinition(
         solid_defs=[return_one, add_one],
+        name="test",
         dependencies={"add_one": {"num": DependencyDefinition("return_one")}},
     )
     run_config = {"storage": {"filesystem": {}}}
@@ -758,7 +788,7 @@ def test_reexecution_fs_storage_with_solid_selection():
         pipeline_def,
         parent_run_id=pipeline_result.run_id,
         run_config=run_config,
-        step_keys_to_execute=["return_one.compute"],
+        step_selection=["return_one"],
         instance=instance,
     )
     assert reexecution_result_no_solid_selection.success
@@ -768,7 +798,10 @@ def test_reexecution_fs_storage_with_solid_selection():
 
     # Case 2: re-execute a pipeline when the original pipeline has solid selection
     pipeline_result_solid_selection = execute_pipeline(
-        pipeline_def, run_config=run_config, instance=instance, solid_selection=["return_one"],
+        pipeline_def,
+        run_config=run_config,
+        instance=instance,
+        solid_selection=["return_one"],
     )
     assert pipeline_result_solid_selection.success
     assert len(pipeline_result_solid_selection.solid_result_list) == 1
@@ -793,13 +826,13 @@ def test_reexecution_fs_storage_with_solid_selection():
     #   re-exeucte a step which hasn't been included in the original pipeline
     with pytest.raises(
         DagsterExecutionStepNotFoundError,
-        match=re.escape("Execution plan does not contain step: add_one.compute"),
+        match="Can not build subset plan from unknown step: add_one",
     ):
         reexecute_pipeline(
             pipeline_def,
             parent_run_id=pipeline_result_solid_selection.run_id,
             run_config=run_config,
-            step_keys_to_execute=["add_one.compute"],
+            step_selection=["add_one"],
             instance=instance,
         )
 
@@ -810,7 +843,7 @@ def test_reexecution_fs_storage_with_solid_selection():
         parent_run_id=reexecution_result_solid_selection.run_id,
         run_config=run_config,
         instance=instance,
-        step_keys_to_execute=["return_one.compute"],
+        step_selection=["return_one"],
     )
 
     assert re_reexecution_result.success
@@ -829,6 +862,7 @@ def test_single_step_reexecution():
 
     pipeline_def = PipelineDefinition(
         solid_defs=[return_one, add_one],
+        name="test",
         dependencies={"add_one": {"num": DependencyDefinition("return_one")}},
     )
     run_config = {"storage": {"filesystem": {}}}
@@ -843,7 +877,7 @@ def test_single_step_reexecution():
         parent_run_id=pipeline_result.run_id,
         run_config=run_config,
         instance=instance,
-        step_keys_to_execute=["add_one.compute"],
+        step_selection=["add_one"],
     )
 
     assert reexecution_result.success
@@ -875,7 +909,7 @@ def test_two_step_reexecution():
         parent_run_id=pipeline_result.run_id,
         run_config=run_config,
         instance=instance,
-        step_keys_to_execute=["add_one.compute", "add_one_2.compute"],
+        step_selection=["add_one", "add_one_2"],
     )
     assert reexecution_result.success
     assert reexecution_result.result_for_solid("return_one").output_value() == None
@@ -956,7 +990,7 @@ def test_default_run_id():
         assert uuid.UUID(context.run_id)
         called["run_id"] = context.run_id
 
-    pipeline_def = PipelineDefinition(solid_defs=[check_run_id])
+    pipeline_def = PipelineDefinition(solid_defs=[check_run_id], name="test")
 
     result = execute_pipeline(pipeline_def)
     assert result.run_id == called["run_id"]
